searchNodes=[{"ref":"Cldr.html","title":"Cldr","type":"module","doc":"Cldr provides the core functions to retrieve and manage the CLDR data that supports formatting and localisation. This module provides the core functions to access formatted CLDR data, set and retrieve a current locale and validate certain core data types such as locales, currencies and territories. Cldr functionality is packaged into a several packages that each depend on this one. These additional modules are: Cldr.Number.to_string/2 for formatting numbers and Cldr.Currency.to_string/2 for formatting currencies. These functions are contained in the hex package ex_cldr_numbers. Cldr.List.to_string/2 for formatting lists. These function is contained in the hex package ex_cldr_lists. Cldr.Unit.to_string/2 for formatting SI units. These function is contained in the hex package ex_cldr_units. Cldr.DateTime.to_string/2 for formatting of dates, times and datetimes. This function is contained in the hex package ex_cldr_dates_times."},{"ref":"Cldr.html#all_locale_names/0","title":"Cldr.all_locale_names/0","type":"function","doc":"Returns a list of all the locale names defined in the CLDR repository. Note that not necessarily all of these locales are available since functions are only generated for configured locales which is most cases will be a subset of locales defined in CLDR. See also: requested_locales/1 and known_locales/1"},{"ref":"Cldr.html#available_locale_name?/1","title":"Cldr.available_locale_name?/1","type":"function","doc":"Returns a boolean indicating if the specified locale is available in CLDR. The return value depends on whether the locale is defined in the CLDR repository. It does not necessarily mean the locale is configured for Cldr. See also Cldr.known_locale_name?/2. Arguments locale is any valid locale name returned by Cldr.known_locale_names/1 Examples iex&gt; Cldr.available_locale_name?(&quot;en-AU&quot;) true iex&gt; Cldr.available_locale_name?(&quot;en-SA&quot;) false"},{"ref":"Cldr.html#default_backend/0","title":"Cldr.default_backend/0","type":"function","doc":"Returns the default backend module. The default backend is configured in config.exs under the ex_cldr key as follows: config :ex_cldr, default_backend: &lt;backend_module&gt; If this function is called and no default backend is configured an exception will be raised."},{"ref":"Cldr.html#default_locale/0","title":"Cldr.default_locale/0","type":"function","doc":"Returns the default locale. Example iex&gt; Cldr.default_locale %Cldr.LanguageTag{ canonical_locale_name: &quot;en-Latn-001&quot;, cldr_locale_name: &quot;en-001&quot;, language_subtags: [], extensions: %{}, gettext_locale_name: nil, language: &quot;en&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;en&quot;, requested_locale_name: &quot;en-001&quot;, script: &quot;Latn&quot;, territory: &quot;001&quot;, transform: %{}, language_variant: nil }"},{"ref":"Cldr.html#default_locale/1","title":"Cldr.default_locale/1","type":"function","doc":"Returns the default locale for a given backend. Arguments backend is any module that includes use Cldr and therefore is a Cldr backend module Example iex&gt; Cldr.default_locale(TestBackend.Cldr) %Cldr.LanguageTag{ canonical_locale_name: &quot;en-Latn-001&quot;, cldr_locale_name: &quot;en-001&quot;, language_subtags: [], extensions: %{}, gettext_locale_name: &quot;en&quot;, language: &quot;en&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;en&quot;, requested_locale_name: &quot;en-001&quot;, script: &quot;Latn&quot;, territory: &quot;001&quot;, transform: %{}, language_variant: nil }"},{"ref":"Cldr.html#default_territory/1","title":"Cldr.default_territory/1","type":"function","doc":"Returns the default territory when a locale does not specify one and none can be inferred. Arguments backend is any module that includes use Cldr and therefore is a Cldr backend module Example iex&gt; Cldr.default_territory(TestBackend.Cldr) :&quot;001&quot;"},{"ref":"Cldr.html#ellipsis/3","title":"Cldr.ellipsis/3","type":"function","doc":"Add locale-specific ellipsis to a string. Arguments string is any valid Elixir string backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0. Note that Cldr.default_backend/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs. options is a keyword list of options Options :locale is any valid locale name returned by Cldr.known_locale_names/1. The default is Cldr.get_locale/0 :location determines where to place the ellipsis. The options are :after (the default for a single string argument), :between (the default and only valid location for an argument that is a list of two strings) and :before Examples iex&gt; Cldr.ellipsis &quot;And furthermore&quot;, MyApp.Cldr &quot;And furthermore…&quot; iex&gt; Cldr.ellipsis [&quot;And furthermore&quot;, &quot;there is much to be done&quot;], MyApp.Cldr, locale: &quot;ja&quot; &quot;And furthermore…there is much to be done&quot;"},{"ref":"Cldr.html#flag/1","title":"Cldr.flag/1","type":"function","doc":"Returns a unicode string representing a flag for a territory. Options territory is any valid territory code returned by Cldr.known_territories/0 or a Cldr.LanguageTag.t Returns A string representing a flag or An empty string if the territory is valid but no unicode grapheme is defined. This is true for territories that are aggregate areas such as &quot;the world&quot; which is &quot;001&quot; {:error, {Cldr.UnknownTerritoryError, message}} Examples iex&gt; Cldr.flag :AU &quot;🇦🇺&quot; iex&gt; Cldr.flag :US &quot;🇺🇸&quot; iex&gt; Cldr.flag &quot;UN&quot; &quot;🇺🇳&quot; iex&gt; Cldr.flag :UK {:error, {Cldr.UnknownTerritoryError, &quot;The territory :UK is unknown&quot;}}"},{"ref":"Cldr.html#get_locale/0","title":"Cldr.get_locale/0","type":"function","doc":"Return the Cldr locale for the current process. Note that the locale is set per-process. If the locale is not set for the given process then: Return the global default locale which is defined under the :ex_cldr key in config.exs Or the system-wide default locale which is %Cldr.LanguageTag{canonical_locale_name: &quot;en-Latn-001&quot;, cldr_locale_name: &quot;en-001&quot;, extensions: %{}, gettext_locale_name: nil, language: &quot;en&quot;, language_subtags: [], language_variant: nil, locale: %{}, private_use: [], rbnf_locale_name: &quot;en&quot;, requested_locale_name: &quot;en-001&quot;, script: &quot;Latn&quot;, territory: &quot;001&quot;, transform: %{}} Note that if there is no locale set for the current process then an error is not returned - a default locale will be returned per the rules above. Example iex&gt; Cldr.put_locale(TestBackend.Cldr.Locale.new!(&quot;pl&quot;)) iex&gt; Cldr.get_locale() %Cldr.LanguageTag{ canonical_locale_name: &quot;pl-Latn-PL&quot;, cldr_locale_name: &quot;pl&quot;, extensions: %{}, language: &quot;pl&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;pl&quot;, territory: &quot;PL&quot;, requested_locale_name: &quot;pl&quot;, script: &quot;Latn&quot;, transform: %{}, language_variant: nil }"},{"ref":"Cldr.html#get_locale/1","title":"Cldr.get_locale/1","type":"function","doc":"Return the backend&#39;s locale for the current process. Note that the locale is set per-process. If the locale is not set for the given process then: return the current processes default locale or if not set, return the default locale of the specified backend or if that is not set, return the global default locale which is defined under the :ex_cldr key in config.exs Or the system-wide default locale which is %Cldr.LanguageTag{canonical_locale_name: &quot;en-Latn-001&quot;, cldr_locale_name: &quot;en-001&quot;, extensions: %{}, gettext_locale_name: nil, language: &quot;en&quot;, language_subtags: [], language_variant: nil, locale: %{}, private_use: [], rbnf_locale_name: &quot;en&quot;, requested_locale_name: &quot;en-001&quot;, script: &quot;Latn&quot;, territory: &quot;001&quot;, transform: %{}} Note that if there is no locale set for the current process then an error is not returned - a default locale will be returned per the rules above. Arguments backend is any module that includes use Cldr and therefore is a Cldr backend module Example iex&gt; Cldr.put_locale(TestBackend.Cldr, &quot;pl&quot;) iex&gt; Cldr.get_locale(TestBackend.Cldr) %Cldr.LanguageTag{ canonical_locale_name: &quot;pl-Latn-PL&quot;, cldr_locale_name: &quot;pl&quot;, extensions: %{}, language: &quot;pl&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;pl&quot;, territory: &quot;PL&quot;, requested_locale_name: &quot;pl&quot;, script: &quot;Latn&quot;, transform: %{}, language_variant: nil }"},{"ref":"Cldr.html#known_calendars/0","title":"Cldr.known_calendars/0","type":"function","doc":"Returns a list of strings representing the calendars known to Cldr. Example iex&gt; Cldr.known_calendars [:buddhist, :chinese, :coptic, :dangi, :ethiopic, :ethiopic_amete_alem, :gregorian, :hebrew, :indian, :islamic, :islamic_civil, :islamic_rgsa, :islamic_tbla, :islamic_umalqura, :japanese, :persian, :roc]"},{"ref":"Cldr.html#known_currencies/0","title":"Cldr.known_currencies/0","type":"function","doc":"Returns a list of strings representing the currencies known to Cldr. Example iex&gt; Cldr.known_currencies [:XBB, :XEU, :SKK, :AUD, :CZK, :ISJ, :BRC, :IDR, :UYP, :VEF, :UAH, :KMF, :NGN, :NAD, :LUC, :AWG, :BRZ, :AOK, :SHP, :DEM, :UGS, :ECS, :BRR, :HUF, :INR, :TPE, :GYD, :MCF, :USS, :ALK, :TJR, :BGO, :BUK, :DKK, :LSL, :AZM, :ZRN, :MKN, :GHC, :JMD, :NOK, :GWP, :CVE, :RUR, :BDT, :NIC, :LAK, :XFO, :KHR, :SRD, :ESB, :PGK, :YUD, :BRN, :MAD, :PYG, :QAR, :MOP, :BOB, :CHW, :PHP, :SDG, :SEK, :KZT, :SDP, :ZWD, :XTS, :SRG, :ANG, :CLF, :BOV, :XBA, :TMT, :TJS, :CUC, :SUR, :MAF, :BRL, :PLZ, :PAB, :AOA, :ZWR, :UGX, :PTE, :NPR, :BOL, :MRO, :MXN, :ATS, :ARP, :KWD, :CLE, :NLG, :TMM, :SAR, :PEN, :PKR, :RUB, :AMD, :MDL, :XRE, :AOR, :MZN, :ESA, :XOF, :CNX, :ILR, :KRW, :CDF, :VND, :DJF, :FKP, :BIF, :FJD, :MYR, :BBD, :GEK, :PES, :CNY, :GMD, :SGD, :MTP, :ZMW, :MWK, :BGN, :GEL, :TTD, :LVL, :XCD, :ARL, :EUR, :UYU, :ZAL, :CSD, :ECV, :GIP, :CLP, :KRH, :CYP, :TWD, :SBD, :SZL, :IRR, :LRD, :CRC, :XDR, :SYP, :YUM, :SIT, :DOP, :MVP, :BWP, :KPW, :GNS, :ZMK, :BZD, :TRY, :MLF, :KES, :MZE, :ALL, :JOD, :HTG, :TND, :ZAR, :LTT, :BGL, :XPD, :CSK, :SLL, :BMD, :BEF, :FIM, :ARA, :ZRZ, :CHF, :SOS, :KGS, :GWE, :LTL, :ITL, :DDM, :ERN, :BAM, :BRB, :ARS, :RHD, :STD, :RWF, :GQE, :HRD, :ILP, :YUR, :AON, :BYR, :RSD, :ZWL, :XBD, :XFU, :GBP, :VEB, :BTN, :UZS, :BGM, :BAD, :MMK, :XBC, :LUF, :BSD, :XUA, :GRD, :CHE, :JPY, :EGP, :XAG, :LYD, :XAU, :USD, :BND, :XPT, :BRE, :ROL, :PLN, :MZM, :FRF, :MGF, :LUL, :SSP, :DZD, :IEP, :SDD, :ADP, :AFN, :IQD, :GHS, :TOP, :LVR, :YUN, :MRU, :MKD, :GNF, :MXP, :THB, :CNH, :TZS, :XPF, :AED, :SVC, :RON, :BEC, :CUP, :USN, :LBP, :BOP, :BHD, :UYW, :BAN, :MDC, :VUV, :MGA, :ISK, :COP, :BYN, :UAK, :TRL, :SCR, :KRO, :ILS, :ETB, :CAD, :AZN, :VNN, :NIO, :COU, :EEK, :KYD, :MNT, :HNL, :WST, :PEI, :YER, :MTL, :STN, :AFA, :ARM, :HKD, :NZD, :VES, :UYI, :MXV, :GTQ, :BYB, :XXX, :XSU, :HRK, :OMR, :BEL, :MUR, :ESP, :YDD, :MVR, :LKR, :XAF]"},{"ref":"Cldr.html#known_gettext_locale_name/2","title":"Cldr.known_gettext_locale_name/2","type":"function","doc":"Returns either the Gettext locale_name in Cldr format or false based upon whether the locale name is configured in GetText. Arguments locale is any valid locale name returned by Cldr.known_locale_names/1 backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0. Note that Cldr.default_backend/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs. Examples iex&gt; Cldr.known_gettext_locale_name(&quot;en&quot;, TestBackend.Cldr) &quot;en&quot; iex&gt; Cldr.known_gettext_locale_name(&quot;en-SA&quot;, TestBackend.Cldr) false"},{"ref":"Cldr.html#known_gettext_locale_name?/2","title":"Cldr.known_gettext_locale_name?/2","type":"function","doc":"Returns a boolean indicating if the specified locale name is configured and available in Gettext. Arguments locale is any valid locale name returned by Cldr.known_locale_names/1 backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0. Note that Cldr.default_backend/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs. Examples iex&gt; Cldr.known_gettext_locale_name?(&quot;en&quot;, TestBackend.Cldr) true iex&gt; Cldr.known_gettext_locale_name?(&quot;!!&quot;, TestBackend.Cldr) false"},{"ref":"Cldr.html#known_gettext_locale_names/1","title":"Cldr.known_gettext_locale_names/1","type":"function","doc":"Returns a list of GetText locale names but in CLDR format with underscore replaces by hyphen in order to facilitate comparisons with Cldr locale names. Arguments backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0. Note that Cldr.default_backend/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs."},{"ref":"Cldr.html#known_locale_name/2","title":"Cldr.known_locale_name/2","type":"function","doc":"Returns either the locale_name or false based upon whether the locale name is configured in Cldr. This is helpful when building a list of or expressions to return the first known locale name from a list. Arguments locale is any valid locale name returned by Cldr.known_locale_names/1 backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0. Note that Cldr.default_backend/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs. Examples iex&gt; Cldr.known_locale_name(&quot;en-AU&quot;, TestBackend.Cldr) &quot;en-AU&quot; iex&gt; Cldr.known_locale_name(&quot;en-SA&quot;, TestBackend.Cldr) false"},{"ref":"Cldr.html#known_locale_name?/2","title":"Cldr.known_locale_name?/2","type":"function","doc":"Returns a boolean indicating if the specified locale name is configured and available in Cldr. Arguments locale is any valid locale name returned by Cldr.known_locale_names/1 backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0. Note that Cldr.default_backend/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs. Examples iex&gt; Cldr.known_locale_name?(&quot;en&quot;, TestBackend.Cldr) true iex&gt; Cldr.known_locale_name?(&quot;!!&quot;, TestBackend.Cldr) false"},{"ref":"Cldr.html#known_locale_names/1","title":"Cldr.known_locale_names/1","type":"function","doc":"Returns a list of the known locale names. Arguments backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0. Note that Cldr.default_backend/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs. Known locales are those locales which are the subset of all CLDR locales that have been configured for use either directly in the config.exs file or in Gettext."},{"ref":"Cldr.html#known_number_system_types/1","title":"Cldr.known_number_system_types/1","type":"function","doc":"Returns a list of atoms representing the number systems types known to Cldr. Arguments backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0. Note that Cldr.default_backend/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs. Example iex&gt; Cldr.known_number_system_types(TestBackend.Cldr) [:default, :finance, :native, :traditional]"},{"ref":"Cldr.html#known_number_systems/0","title":"Cldr.known_number_systems/0","type":"function","doc":"Returns a list of atoms representing the number systems known to Cldr. Example iex&gt; Cldr.known_number_systems [:adlm, :ahom, :arab, :arabext, :armn, :armnlow, :bali, :beng, :bhks, :brah, :cakm, :cham, :cyrl, :deva, :ethi, :fullwide, :geor, :gong, :gonm, :grek, :greklow, :gujr, :guru, :hanidays, :hanidec, :hans, :hansfin, :hant, :hantfin, :hebr, :hmng, :hmnp, :java, :jpan, :jpanfin, :jpanyear, :kali, :khmr, :knda, :lana, :lanatham, :laoo, :latn, :lepc, :limb, :mathbold, :mathdbl, :mathmono, :mathsanb, :mathsans, :mlym, :modi, :mong, :mroo, :mtei, :mymr, :mymrshan, :mymrtlng, :newa, :nkoo, :olck, :orya, :osma, :rohg, :roman, :romanlow, :saur, :shrd, :sind, :sinh, :sora, :sund, :takr, :talu, :taml, :tamldec, :telu, :thai, :tibt, :tirh, :vaii, :wara, :wcho]"},{"ref":"Cldr.html#known_rbnf_locale_name/2","title":"Cldr.known_rbnf_locale_name/2","type":"function","doc":"Returns either the RBNF locale_name or false based upon whether the locale name is configured in Cldr and has RBNF rules defined. Arguments locale is any valid locale name returned by Cldr.known_locale_names/1 backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0. Note that Cldr.default_backend/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs. Examples iex&gt; Cldr.known_rbnf_locale_name(&quot;en&quot;, TestBackend.Cldr) &quot;en&quot; iex&gt; Cldr.known_rbnf_locale_name(&quot;en-SA&quot;, TestBackend.Cldr) false"},{"ref":"Cldr.html#known_rbnf_locale_name?/2","title":"Cldr.known_rbnf_locale_name?/2","type":"function","doc":"Returns a boolean indicating if the specified locale name is configured and available in Cldr and supports rules based number formats (RBNF). Arguments locale is any valid locale name returned by Cldr.known_locale_names/1 backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0. Note that Cldr.default_backend/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs. Examples iex&gt; Cldr.known_rbnf_locale_name?(&quot;en&quot;, TestBackend.Cldr) true iex&gt; Cldr.known_rbnf_locale_name?(&quot;!!&quot;, TestBackend.Cldr) false"},{"ref":"Cldr.html#known_rbnf_locale_names/1","title":"Cldr.known_rbnf_locale_names/1","type":"function","doc":"Returns a list of locale names which have rules based number formats (RBNF). Arguments backend is any module that includes use Cldr and therefore is a Cldr backend module"},{"ref":"Cldr.html#known_territories/0","title":"Cldr.known_territories/0","type":"function","doc":"Returns a list of the territories known to Cldr. The territories codes are defined in UN M.49 which defines both individual territories and enclosing territories. These enclosing territories are defined for statistical purposes and do not relate to political alignment. For example, the territory :&quot;001&quot; is defined as &quot;the world&quot;. Example iex&gt; Cldr.known_territories [:&quot;001&quot;, :&quot;002&quot;, :&quot;003&quot;, :&quot;005&quot;, :&quot;009&quot;, :&quot;011&quot;, :&quot;013&quot;, :&quot;014&quot;, :&quot;015&quot;, :&quot;017&quot;, :&quot;018&quot;, :&quot;019&quot;, :&quot;021&quot;, :&quot;029&quot;, :&quot;030&quot;, :&quot;034&quot;, :&quot;035&quot;, :&quot;039&quot;, :&quot;053&quot;, :&quot;054&quot;, :&quot;057&quot;, :&quot;061&quot;, :&quot;142&quot;, :&quot;143&quot;, :&quot;145&quot;, :&quot;150&quot;, :&quot;151&quot;, :&quot;154&quot;, :&quot;155&quot;, :&quot;202&quot;, :&quot;419&quot;, :AC, :AD, :AE, :AF, :AG, :AI, :AL, :AM, :AO, :AQ, :AR, :AS, :AT, :AU, :AW, :AX, :AZ, :BA, :BB, :BD, :BE, :BF, :BG, :BH, :BI, :BJ, :BL, :BM, :BN, :BO, :BQ, :BR, :BS, :BT, :BV, :BW, :BY, :BZ, :CA, :CC, :CD, :CF, :CG, :CH, :CI, :CK, :CL, :CM, :CN, :CO, :CP, :CR, :CU, :CV, :CW, :CX, :CY, :CZ, :DE, :DG, :DJ, :DK, :DM, :DO, :DZ, :EA, :EC, :EE, :EG, :EH, :ER, :ES, :ET, :EU, :EZ, :FI, :FJ, :FK, :FM, :FO, :FR, :GA, :GB, :GD, :GE, :GF, :GG, :GH, :GI, :GL, :GM, :GN, :GP, :GQ, :GR, :GS, :GT, :GU, :GW, :GY, :HK, :HM, :HN, :HR, :HT, :HU, :IC, :ID, :IE, :IL, :IM, :IN, :IO, :IQ, :IR, :IS, :IT, :JE, :JM, :JO, :JP, :KE, :KG, :KH, :KI, :KM, :KN, :KP, :KR, :KW, :KY, :KZ, :LA, :LB, :LC, :LI, :LK, :LR, :LS, :LT, :LU, :LV, :LY, :MA, :MC, :MD, :ME, :MF, :MG, :MH, :MK, :ML, :MM, :MN, :MO, :MP, :MQ, :MR, :MS, :MT, :MU, :MV, :MW, :MX, :MY, :MZ, :NA, :NC, :NE, :NF, :NG, :NI, :NL, :NO, :NP, :NR, :NU, :NZ, :OM, :PA, :PE, :PF, :PG, :PH, :PK, :PL, :PM, :PN, :PR, :PS, :PT, :PW, :PY, :QA, :QO, :RE, :RO, :RS, :RU, :RW, :SA, :SB, :SC, :SD, :SE, :SG, :SH, :SI, :SJ, :SK, :SL, :SM, :SN, :SO, :SR, :SS, :ST, :SV, :SX, :SY, :SZ, :TA, :TC, :TD, :TF, :TG, :TH, :TJ, :TK, :TL, :TM, :TN, :TO, :TR, :TT, :TV, :TW, :TZ, :UA, :UG, :UM, :UN, :US, :UY, :UZ, :VA, :VC, :VE, :VG, :VI, :VN, :VU, :WF, :WS, :XK, :YE, :YT, :ZA, :ZM, :ZW]"},{"ref":"Cldr.html#put_locale/1","title":"Cldr.put_locale/1","type":"function","doc":"Set the current process&#39;s locale for all backends. This is the preferred approach. Arguments locale is a Cldr.LanguageTag struct returned by Cldr.Locale.new!/2 Note that the argument must be a Cldr.LanguageTag struct with a non-nil :cldr_locale_name. Examples iex&gt; Cldr.put_locale(TestBackend.Cldr.Locale.new!(&quot;en&quot;)) {:ok, %Cldr.LanguageTag{ canonical_locale_name: &quot;en-Latn-US&quot;, cldr_locale_name: &quot;en&quot;, language_subtags: [], extensions: %{}, gettext_locale_name: &quot;en&quot;, language: &quot;en&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;en&quot;, requested_locale_name: &quot;en&quot;, script: &quot;Latn&quot;, territory: &quot;US&quot;, transform: %{}, language_variant: nil }}"},{"ref":"Cldr.html#put_locale/2","title":"Cldr.put_locale/2","type":"function","doc":"Set the current process&#39;s locale for a specified backend. Arguments locale is any valid locale name returned by Cldr.known_locale_names/1 or a Cldr.LanguageTag struct returned by Cldr.Locale.new!/2 backend is any module that includes use Cldr and therefore is a Cldr backend module See rfc5646 for the specification of a language tag and consult ./priv/cldr/rfc5646.abnf for the specification as implemented that includes the CLDR extensions for &quot;u&quot; (locales) and &quot;t&quot; (transforms). Examples iex&gt; Cldr.put_locale(TestBackend.Cldr, &quot;en&quot;) {:ok, %Cldr.LanguageTag{ canonical_locale_name: &quot;en-Latn-US&quot;, cldr_locale_name: &quot;en&quot;, language_subtags: [], extensions: %{}, gettext_locale_name: &quot;en&quot;, language: &quot;en&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;en&quot;, requested_locale_name: &quot;en&quot;, script: &quot;Latn&quot;, territory: &quot;US&quot;, transform: %{}, language_variant: nil }} iex&gt; Cldr.put_locale(TestBackend.Cldr, &quot;invalid-locale&quot;) {:error, {Cldr.LanguageTag.ParseError, &quot;Expected a BCP47 language tag. Could not parse the remaining \\&quot;le\\&quot; starting at position 13&quot;}}"},{"ref":"Cldr.html#quote/3","title":"Cldr.quote/3","type":"function","doc":"Add locale-specific quotation marks around a string. Arguments string is any valid Elixir string backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0. Note that Cldr.default_backend/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs. options is a keyword list of options Options :locale is any valid locale name returned by Cldr.known_locale_names/1. The default is Cldr.get_locale/0 Examples iex&gt; Cldr.quote &quot;Quoted String&quot;, MyApp.Cldr &quot;“Quoted String”&quot; iex&gt; Cldr.quote &quot;Quoted String&quot;, MyApp.Cldr, locale: &quot;ja&quot; &quot;「Quoted String」&quot;"},{"ref":"Cldr.html#requested_locale_names/1","title":"Cldr.requested_locale_names/1","type":"function","doc":"Returns a list of all requested locale names. Arguments backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0. Note that Cldr.default_backend/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs. The list is the combination of configured locales, Gettext locales and the default locale. See also known_locales/1 and all_locales/0"},{"ref":"Cldr.html#unknown_calendar_error/1","title":"Cldr.unknown_calendar_error/1","type":"function","doc":"Returns an error tuple for an invalid calendar. Arguments calendar is any calendar name not returned by Cldr.known_calendars/0 Returns {:error, {Cldr.UnknownCalendarError, message}} Examples iex&gt; Cldr.unknown_calendar_error(&quot;invalid&quot;) {Cldr.UnknownCalendarError, &quot;The calendar name \\&quot;invalid\\&quot; is invalid&quot;}"},{"ref":"Cldr.html#unknown_currency_error/1","title":"Cldr.unknown_currency_error/1","type":"function","doc":"Returns an error tuple for an invalid currency. Arguments currency is any currency code not returned by Cldr.known_currencies/0 Returns {:error, {Cldr.UnknownCurrencyError, message}} Examples iex&gt; Cldr.unknown_currency_error(&quot;invalid&quot;) {Cldr.UnknownCurrencyError, &quot;The currency \\&quot;invalid\\&quot; is invalid&quot;}"},{"ref":"Cldr.html#unknown_locale_names/1","title":"Cldr.unknown_locale_names/1","type":"function","doc":"Returns a list of the locales names that are configured, but not known in CLDR. Arguments backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0. Note that Cldr.default_backend/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs. Since there is a compile-time exception raise if there are any unknown locales this function should always return an empty list."},{"ref":"Cldr.html#unknown_number_system_error/1","title":"Cldr.unknown_number_system_error/1","type":"function","doc":"Returns an error tuple for an unknown number system. Arguments number_system is any number system name not returned by Cldr.known_number_systems/0 Returns {:error, {Cldr.UnknownNumberSystemError, message}} Examples iex&gt; Cldr.unknown_number_system_error &quot;invalid&quot; {Cldr.UnknownNumberSystemError, &quot;The number system \\&quot;invalid\\&quot; is invalid&quot;} iex&gt; Cldr.unknown_number_system_error :invalid {Cldr.UnknownNumberSystemError, &quot;The number system :invalid is unknown&quot;}"},{"ref":"Cldr.html#unknown_number_system_type_error/1","title":"Cldr.unknown_number_system_type_error/1","type":"function","doc":"Returns an error tuple for an unknown number system type. Options number_system_type is any number system type name not returned by Cldr.known_number_system_types/1 Returns {:error, {Cldr.UnknownNumberSystemTypeError, message}} Examples iex&gt; Cldr.unknown_number_system_type_error(&quot;invalid&quot;) {Cldr.UnknownNumberSystemTypeError, &quot;The number system type \\&quot;invalid\\&quot; is invalid&quot;} iex&gt; Cldr.unknown_number_system_type_error(:invalid) {Cldr.UnknownNumberSystemTypeError, &quot;The number system type :invalid is unknown&quot;}"},{"ref":"Cldr.html#unknown_plural_type_error/1","title":"Cldr.unknown_plural_type_error/1","type":"function","doc":"Returns an error tuple for an unknown plural type. Options plural_type is any number system type name not returned by Cldr.Number.PluralRule.known_plural_types/0 Returns {:error, {Cldr.UnknownPluralTypeError, message}} Examples iex&gt; Cldr.unknown_plural_type_error(&quot;invalid&quot;) {Cldr.UnknownPluralTypeError, &quot;The plural type \\&quot;invalid\\&quot; is invalid&quot;} iex&gt; Cldr.unknown_plural_type_error(:invalid) {Cldr.UnknownPluralTypeError, &quot;The plural type :invalid is unknown&quot;}"},{"ref":"Cldr.html#unknown_territory_error/1","title":"Cldr.unknown_territory_error/1","type":"function","doc":"Returns an error tuple for an unknown territory. Arguments territory is any territory code not returned by Cldr.known_territories/0 Returns {:error, {Cldr.UnknownTerritoryError, message}} Examples iex&gt; Cldr.unknown_territory_error(&quot;invalid&quot;) {Cldr.UnknownTerritoryError, &quot;The territory \\&quot;invalid\\&quot; is unknown&quot;}"},{"ref":"Cldr.html#validate_calendar/1","title":"Cldr.validate_calendar/1","type":"function","doc":"Normalise and validate a calendar name. Arguments calendar is any calendar name returned by Cldr.known_calendars/0 Returns {:ok, normalized_calendar_name} or {:error, {Cldr.UnknownCalendarError, message}} Examples iex&gt; Cldr.validate_calendar(:gregorian) {:ok, :gregorian} iex&gt; Cldr.validate_calendar(:invalid) {:error, {Cldr.UnknownCalendarError, &quot;The calendar name :invalid is invalid&quot;}}"},{"ref":"Cldr.html#validate_currency/1","title":"Cldr.validate_currency/1","type":"function","doc":"Normalize and validate a currency code. Arguments currency is any ISO 4217 currency code as returned by Cldr.known_currencies/0 or any valid private use ISO4217 code which is a three-letter alphabetic code that starts with &quot;X&quot;. Returns {:ok, normalized_currency_code} or {:error, {Cldr.UnknownCurrencyError, message}} Examples iex&gt; Cldr.validate_currency(:USD) {:ok, :USD} iex&gt; Cldr.validate_currency(&quot;USD&quot;) {:ok, :USD} iex&gt; Cldr.validate_currency(:XTC) {:ok, :XTC} iex&gt; Cldr.validate_currency(&quot;xtc&quot;) {:ok, :XTC} iex&gt; Cldr.validate_currency(&quot;invalid&quot;) {:error, {Cldr.UnknownCurrencyError, &quot;The currency \\&quot;invalid\\&quot; is invalid&quot;}} iex&gt; Cldr.validate_currency(:invalid) {:error, {Cldr.UnknownCurrencyError, &quot;The currency :invalid is invalid&quot;}}"},{"ref":"Cldr.html#validate_gettext_locale/2","title":"Cldr.validate_gettext_locale/2","type":"function","doc":"Normalise and validate a gettext locale name. Arguments locale_name is any valid locale name returned by Cldr.known_locale_names/1 or a Cldr.LanguageTag struct returned by Cldr.Locale.new!/2 backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0. Note that Cldr.default_backend/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs. Returns {:ok, language_tag} {:error, reason} Examples"},{"ref":"Cldr.html#validate_locale/2","title":"Cldr.validate_locale/2","type":"function","doc":"Normalise and validate a locale name. Arguments locale is any valid locale name returned by Cldr.known_locale_names/1 or a Cldr.LanguageTag struct returned by Cldr.Locale.new!/2 backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0. Note that Cldr.default_backend/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs. Returns {:ok, language_tag} {:error, reason} Examples iex&gt; Cldr.validate_locale(&quot;en&quot;, TestBackend.Cldr) {:ok, %Cldr.LanguageTag{ canonical_locale_name: &quot;en-Latn-US&quot;, cldr_locale_name: &quot;en&quot;, extensions: %{}, gettext_locale_name: &quot;en&quot;, language: &quot;en&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;en&quot;, requested_locale_name: &quot;en&quot;, script: &quot;Latn&quot;, territory: &quot;US&quot;, transform: %{}, language_variant: nil }} iex&gt; Cldr.validate_locale(&quot;zzz&quot;, TestBackend.Cldr) {:error, {Cldr.UnknownLocaleError, &quot;The locale \\&quot;zzz\\&quot; is not known.&quot;}}"},{"ref":"Cldr.html#validate_number_system/1","title":"Cldr.validate_number_system/1","type":"function","doc":"Normalize and validate a number system name. Arguments number_system is any number system name returned by Cldr.known_number_systems/0 Returns {:ok, normalized_number_system_name} or {:error, {exception, message}} Examples iex&gt; Cldr.validate_number_system :latn {:ok, :latn} iex&gt; Cldr.validate_number_system &quot;latn&quot; {:ok, :latn} iex&gt; Cldr.validate_number_system &quot;invalid&quot; { :error, {Cldr.UnknownNumberSystemError, &quot;The number system :invalid is unknown&quot;} }"},{"ref":"Cldr.html#validate_number_system_type/2","title":"Cldr.validate_number_system_type/2","type":"function","doc":"Normalise and validate a number system type. Arguments number_system_type is any number system type returned by Cldr.known_number_system_types/1 backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0. Note that Cldr.default_backend/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs. Returns {:ok, normalized_number_system_type} or {:error, {exception, message}} Examples iex&gt; Cldr.validate_number_system_type(:default, TestBackend.Cldr) {:ok, :default} iex&gt; Cldr.validate_number_system_type(:traditional, TestBackend.Cldr) {:ok, :traditional} iex&gt; Cldr.validate_number_system_type(:latn, TestBackend.Cldr) { :error, {Cldr.UnknownNumberSystemTypeError, &quot;The number system type :latn is unknown&quot;} }"},{"ref":"Cldr.html#validate_plural_type/1","title":"Cldr.validate_plural_type/1","type":"function","doc":"Normalize and validate a plural type. Arguments plural_type is any plural type returned by Cldr.Number.PluralRule.known_plural_types/0 Returns {:ok, normalized_plural_type} or {:error, {exception, message}} Examples iex&gt; Cldr.validate_plural_type :few {:ok, :few} iex&gt; Cldr.validate_plural_type &quot;one&quot; {:ok, :one} iex&gt; Cldr.validate_plural_type &quot;invalid&quot; { :error, {Cldr.UnknownPluralTypeError, &quot;The plural type :invalid is unknown&quot;} }"},{"ref":"Cldr.html#validate_territory/1","title":"Cldr.validate_territory/1","type":"function","doc":"Normalise and validate a territory code. Arguments territory is any territory code returned by Cldr.known_territories/0 Returns: {:ok, normalized_territory_code} or {:error, {Cldr.UnknownTerritoryError, message}} Examples iex&gt; Cldr.validate_territory(&quot;en&quot;) {:error, {Cldr.UnknownTerritoryError, &quot;The territory \\&quot;en\\&quot; is unknown&quot;}} iex&gt; Cldr.validate_territory(&quot;gb&quot;) {:ok, :GB} iex&gt; Cldr.validate_territory(&quot;001&quot;) {:ok, :&quot;001&quot;} iex&gt; Cldr.validate_territory(Cldr.Locale.new!(&quot;en&quot;, TestBackend.Cldr)) {:ok, :US} iex&gt; Cldr.validate_territory(%{}) {:error, {Cldr.UnknownTerritoryError, &quot;The territory %{} is unknown&quot;}}"},{"ref":"Cldr.html#version/0","title":"Cldr.version/0","type":"function","doc":"Returns the version of the CLDR repository as a tuple Example iex&gt; Cldr.version {36, 0, 0}"},{"ref":"Cldr.html#t:backend/0","title":"Cldr.backend/0","type":"type","doc":""},{"ref":"Cldr.AcceptLanguage.html","title":"Cldr.AcceptLanguage","type":"module","doc":"Tokenizer and parser for HTTP Accept-Language header values as defined in rfc2616. The Accept-Language request-header field is similar to Accept, but restricts the set of natural languages that are preferred as a response to the request. Language tags function are provided in Cldr.LanguageTag. The format of an Accept-Language header is as follows in ABNF format: Accept-Language = &quot;Accept-Language&quot; &quot;:&quot; 1#( language-range [ &quot;;&quot; &quot;q&quot; &quot;=&quot; qvalue ] ) language-range = ( ( 1*8ALPHA *( &quot;-&quot; 1*8ALPHA ) ) | &quot;*&quot; ) Each language-range MAY be given an associated quality value which represents an estimate of the user&#39;s preference for the languages specified by that range. The quality value defaults to &quot;q=1&quot;. For example, Accept-Language: da, en-gb;q=0.8, en;q=0.7 would mean: &quot;I prefer Danish, but will accept British English and other types of English.&quot;"},{"ref":"Cldr.AcceptLanguage.html#best_match/2","title":"Cldr.AcceptLanguage.best_match/2","type":"function","doc":"Parse an Accept-Language string and return the best match for a configured Cldr locale. accept_langauge is a string representing an accept language header Returns: {:ok, language_tag} or {:error, reason} Examples iex&gt; Cldr.AcceptLanguage.best_match(&quot;da;q=0.1,zh-TW;q=0.3&quot;, TestBackend.Cldr) {:ok, %Cldr.LanguageTag{ canonical_locale_name: &quot;zh-Hant-TW&quot;, cldr_locale_name: &quot;zh-Hant&quot;, language_subtags: [], extensions: %{}, gettext_locale_name: nil, language: &quot;zh&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;zh-Hant&quot;, requested_locale_name: &quot;zh-TW&quot;, script: &quot;Hant&quot;, territory: &quot;TW&quot;, transform: %{}, language_variant: nil }} iex(4)&gt; Cldr.AcceptLanguage.best_match(&quot;da;q=0.1,zh-TW;q=0.3&quot;, TestBackend.Cldr) {:ok, %Cldr.LanguageTag{ canonical_locale_name: &quot;zh-Hant-TW&quot;, cldr_locale_name: &quot;zh-Hant&quot;, language_subtags: [], extensions: %{}, gettext_locale_name: nil, language: &quot;zh&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;zh-Hant&quot;, requested_locale_name: &quot;zh-TW&quot;, script: &quot;Hant&quot;, territory: &quot;TW&quot;, transform: %{}, language_variant: nil }} iex&gt; Cldr.AcceptLanguage.best_match(&quot;xx,yy;q=0.3&quot;, TestBackend.Cldr) {:error, {Cldr.NoMatchingLocale, &quot;No configured locale could be matched to \\&quot;xx,yy;q=0.3\\&quot;&quot;}} iex&gt; Cldr.AcceptLanguage.best_match(&quot;invalid_tag&quot;, TestBackend.Cldr) {:error, {Cldr.LanguageTag.ParseError, &quot;Expected a BCP47 language tag. Could not parse the remaining \\&quot;g\\&quot; starting at position 11&quot;}}"},{"ref":"Cldr.AcceptLanguage.html#errors/1","title":"Cldr.AcceptLanguage.errors/1","type":"function","doc":"Filters the returned results of parse/1 to return only the error tuples. Example iex&gt; Cldr.AcceptLanguage.parse!(&quot;da,zh-TW;q=0.3,invalid_tag&quot;, TestBackend.Cldr) ...&gt; |&gt; Cldr.AcceptLanguage.errors [ error: {Cldr.LanguageTag.ParseError, &quot;Expected a BCP47 language tag. Could not parse the remaining \\&quot;g\\&quot; starting at position 11&quot;} ]"},{"ref":"Cldr.AcceptLanguage.html#parse/2","title":"Cldr.AcceptLanguage.parse/2","type":"function","doc":"Parses an Accept-Language header value in its string or tokenized form to return a tuple of the form {:ok, [{quality, %Cldr.LanguageTag{}}, ...]} sorted by quality. Arguments accept-language is any string in the format defined by rfc2616 backend is any module that includes use Cldr and therefore is a Cldr backend module Returns {:ok, [{quality, language_tag}, ...]} or {:error, {Cldr.AcceptLanguageError, String.t}} If at least one valid language tag is found but errors are also detected on one more more tags, an {ok, list} tuple is returned wuth an error tuple for each invalid tag added at the end of the list. Example iex&gt; Cldr.AcceptLanguage.parse(&quot;da,zh-TW;q=0.3&quot;, TestBackend.Cldr) {:ok, [ {1.0, %Cldr.LanguageTag{ canonical_locale_name: &quot;da-Latn-DK&quot;, cldr_locale_name: &quot;da&quot;, language_subtags: [], extensions: %{}, gettext_locale_name: nil, language: &quot;da&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;da&quot;, requested_locale_name: &quot;da&quot;, script: &quot;Latn&quot;, territory: &quot;DK&quot;, transform: %{}, language_variant: nil }}, {0.3, %Cldr.LanguageTag{ canonical_locale_name: &quot;zh-Hant-TW&quot;, cldr_locale_name: &quot;zh-Hant&quot;, language_subtags: [], extensions: %{}, gettext_locale_name: nil, language: &quot;zh&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;zh-Hant&quot;, requested_locale_name: &quot;zh-TW&quot;, script: &quot;Hant&quot;, territory: &quot;TW&quot;, transform: %{}, language_variant: nil }} ]} iex&gt; Cldr.AcceptLanguage.parse(&quot;invalid_tag&quot;, TestBackend.Cldr) {:error, {Cldr.LanguageTag.ParseError, &quot;Expected a BCP47 language tag. Could not parse the remaining \\&quot;g\\&quot; starting at position 11&quot;}} iex&gt; Cldr.AcceptLanguage.parse(&quot;da,zh-TW;q=0.3,invalid_tag&quot;, TestBackend.Cldr) {:ok, [ {1.0, %Cldr.LanguageTag{ canonical_locale_name: &quot;da-Latn-DK&quot;, cldr_locale_name: &quot;da&quot;, language_subtags: [], extensions: %{}, gettext_locale_name: nil, language: &quot;da&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;da&quot;, requested_locale_name: &quot;da&quot;, script: &quot;Latn&quot;, territory: &quot;DK&quot;, transform: %{}, language_variant: nil }}, {0.3, %Cldr.LanguageTag{ canonical_locale_name: &quot;zh-Hant-TW&quot;, cldr_locale_name: &quot;zh-Hant&quot;, language_subtags: [], extensions: %{}, gettext_locale_name: nil, language: &quot;zh&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;zh-Hant&quot;, requested_locale_name: &quot;zh-TW&quot;, script: &quot;Hant&quot;, territory: &quot;TW&quot;, transform: %{}, language_variant: nil }}, {:error, {Cldr.LanguageTag.ParseError, &quot;Expected a BCP47 language tag. Could not parse the remaining \\&quot;g\\&quot; starting at position 11&quot;}} ]}"},{"ref":"Cldr.AcceptLanguage.html#parse!/2","title":"Cldr.AcceptLanguage.parse!/2","type":"function","doc":"Parses an Accept-Language header value in its string or tokenized form to produce a list of tuples of the form [{quality, %Cldr.LanguageTag{}}, ...] sorted by quality in decending order. accept-language is any string in the format defined by rfc2616 Returns: {:ok, [{quality, language_tag}, ...]} or raises a Cldr.AcceptLanguageError exception If at least one valid language tag is found but errors are also detected on one more more tags, an {ok, list} tuple is returned wuth an error tuple for each invalid tag added at the end of the list. Example iex&gt; Cldr.AcceptLanguage.parse!(&quot;da,zh-TW;q=0.3&quot;, TestBackend.Cldr) [ {1.0, %Cldr.LanguageTag{ canonical_locale_name: &quot;da-Latn-DK&quot;, cldr_locale_name: &quot;da&quot;, language_subtags: [], extensions: %{}, gettext_locale_name: nil, language: &quot;da&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;da&quot;, requested_locale_name: &quot;da&quot;, script: &quot;Latn&quot;, territory: &quot;DK&quot;, transform: %{}, language_variant: nil }}, {0.3, %Cldr.LanguageTag{ canonical_locale_name: &quot;zh-Hant-TW&quot;, cldr_locale_name: &quot;zh-Hant&quot;, language_subtags: [], extensions: %{}, gettext_locale_name: nil, language: &quot;zh&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;zh-Hant&quot;, requested_locale_name: &quot;zh-TW&quot;, script: &quot;Hant&quot;, territory: &quot;TW&quot;, transform: %{}, language_variant: nil }} ] Cldr.AcceptLanguage.parse! &quot;invalid_tag&quot; ** (Cldr.AcceptLanguageError) &quot;Expected a BCP47 language tag. Could not parse the remaining &quot;g&quot; starting at position 11 (ex_cldr) lib/cldr/accept_language.ex:304: Cldr.AcceptLanguage.parse!/1 iex&gt; Cldr.AcceptLanguage.parse!(&quot;da,zh-TW;q=0.3,invalid_tag&quot;, TestBackend.Cldr) [ {1.0, %Cldr.LanguageTag{ canonical_locale_name: &quot;da-Latn-DK&quot;, cldr_locale_name: &quot;da&quot;, language_subtags: [], extensions: %{}, gettext_locale_name: nil, language: &quot;da&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;da&quot;, requested_locale_name: &quot;da&quot;, script: &quot;Latn&quot;, territory: &quot;DK&quot;, transform: %{}, language_variant: nil }}, {0.3, %Cldr.LanguageTag{ canonical_locale_name: &quot;zh-Hant-TW&quot;, cldr_locale_name: &quot;zh-Hant&quot;, language_subtags: [], extensions: %{}, gettext_locale_name: nil, language: &quot;zh&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;zh-Hant&quot;, requested_locale_name: &quot;zh-TW&quot;, script: &quot;Hant&quot;, territory: &quot;TW&quot;, transform: %{}, language_variant: nil }}, {:error, {Cldr.LanguageTag.ParseError, &quot;Expected a BCP47 language tag. Could not parse the remaining \\&quot;g\\&quot; starting at position 11&quot;}} ]"},{"ref":"Cldr.AcceptLanguage.html#sort_by_quality/1","title":"Cldr.AcceptLanguage.sort_by_quality/1","type":"function","doc":""},{"ref":"Cldr.AcceptLanguage.html#tokenize/1","title":"Cldr.AcceptLanguage.tokenize/1","type":"function","doc":"Splits the language ranges for an Accept-Language header value into tuples {quality, language}. accept-language is any string in the format defined by rfc2616 Example iex&gt; Cldr.AcceptLanguage.tokenize &quot;da,zh-TW;q=0.3&quot; [{1.0, &quot;da&quot;}, {0.3, &quot;zh-tw&quot;}]"},{"ref":"Cldr.AcceptLanguageError.html","title":"Cldr.AcceptLanguageError","type":"exception","doc":"Exception raised when there no valid language tag in an Accept-Language header."},{"ref":"Cldr.FormatCompileError.html","title":"Cldr.FormatCompileError","type":"exception","doc":"Exception raised when there is an error in the compiling of a number format."},{"ref":"Cldr.FormatError.html","title":"Cldr.FormatError","type":"exception","doc":"Exception raised when there is an error in the formatting of a number/list/..."},{"ref":"Cldr.Install.html","title":"Cldr.Install","type":"module","doc":"Provides functions for installing locales. When installed as a package on from hex, Cldr has only the default locales [&quot;en&quot;, &quot;root&quot;] installed and configured. When other locales are added to the configuration Cldr will attempt to download the locale from github during compilation. If Cldr is installed from github directly then all locales are already installed."},{"ref":"Cldr.Install.html#client_data_dir/1","title":"Cldr.Install.client_data_dir/1","type":"function","doc":"See Cldr.Config.client_data_dir/1."},{"ref":"Cldr.Install.html#client_locale_file/2","title":"Cldr.Install.client_locale_file/2","type":"function","doc":"Returns the full pathname of the locale&#39;s json file. locale is any locale returned by Cldr.known_locale_names/1 No checking of locale validity is performed."},{"ref":"Cldr.Install.html#client_locales_dir/1","title":"Cldr.Install.client_locales_dir/1","type":"function","doc":"See Cldr.Config.client_locales_dir/1."},{"ref":"Cldr.Install.html#install_all_locale_names/1","title":"Cldr.Install.install_all_locale_names/1","type":"function","doc":"Install all available locales."},{"ref":"Cldr.Install.html#install_known_locale_names/1","title":"Cldr.Install.install_known_locale_names/1","type":"function","doc":"Install all the configured locales."},{"ref":"Cldr.Install.html#install_locale_name/3","title":"Cldr.Install.install_locale_name/3","type":"function","doc":"Download the requested locale from github into the client application&#39;s cldr data directory. locale is any locale returned by Cldr.known_locale_names/1 options is a keyword list. Currently the only supported option is :force which defaults to false. If truthy the locale will be installed or re-installed. The data directory is typically ./priv/cldr/locales. This function is intended to be invoked during application compilation when a valid locale is configured but is not yet installed in the application. An https request to the master github repository for Cldr is made to download the correct version of the locale file which is then written to the configured data directory."},{"ref":"Cldr.Install.html#locale_filename/1","title":"Cldr.Install.locale_filename/1","type":"function","doc":"See Cldr.Config.locale_filename/1."},{"ref":"Cldr.Install.html#locale_installed?/2","title":"Cldr.Install.locale_installed?/2","type":"function","doc":"Returns a boolean indicating if the requested locale is installed. No checking of the validity of the locale itself is performed. The check is based upon whether there is a locale file installed in the client application or in Cldr itself."},{"ref":"Cldr.InvalidDateFormatType.html","title":"Cldr.InvalidDateFormatType","type":"exception","doc":"Exception raised when there is an invalid date format type."},{"ref":"Cldr.InvalidDateTimeFormatType.html","title":"Cldr.InvalidDateTimeFormatType","type":"exception","doc":"Exception raised when there is an invalid datetime format type."},{"ref":"Cldr.InvalidLanguageTag.html","title":"Cldr.InvalidLanguageTag","type":"exception","doc":"Exception raised when there is an a parse error in a language tag"},{"ref":"Cldr.InvalidTimeFormatType.html","title":"Cldr.InvalidTimeFormatType","type":"exception","doc":"Exception raised when there is an invalid time format type."},{"ref":"Cldr.Locale.html","title":"Cldr.Locale","type":"module","doc":"Functions to parse and normalize locale names into a structure locale represented by a Cldr.LanguageTag. CLDR represents localisation data organized into locales, with each locale being identified by a locale name that is formatted according to RFC5646. In practise, the CLDR data utilizes a simple subset of locale name formats being: a Language code such as en or fr a Language code and Tertitory code such as en-GB a Language code and Script such as zh-Hant and in only two cases a Language code, Territory code and Variant such as ca-ES-VALENCIA and en-US-POSIX. The RFC defines a language tag as: A language tag is composed from a sequence of one or more &quot;subtags&quot;, each of which refines or narrows the range of language identified by the overall tag. Subtags, in turn, are a sequence of alphanumeric characters (letters and digits), distinguished and separated from other subtags in a tag by a hyphen (&quot;-&quot;, [Unicode] U+002D) Therefore Cldr uses the hyphen (&quot;-&quot;, [Unicode] U+002D) as the subtag separator. On certain platforms, including POSIX platforms, the subtag separator is a &quot;_&quot; (underscore) rather than a &quot;-&quot; (hyphen). Where appropriate, Cldr will transliterate any underscore into a hyphen before parsing or processing. Locale name validity When validating a locale name, Cldr will attempt to match the requested locale name to a configured locale. Therefore Cldr.Locale.new/2 may return an {:ok, language_tag} tuple even when the locale returned does not exactly match the requested locale name. For example, the following attempts to create a locale matching the non-existent &quot;english as spoken in Spain&quot; local name. Here Cldr will match to the nearest configured locale, which in this case will be &quot;en&quot;. iex&gt; Cldr.Locale.new(&quot;en-ES&quot;, TestBackend.Cldr) {:ok, %Cldr.LanguageTag{ canonical_locale_name: &quot;en-Latn-ES&quot;, cldr_locale_name: &quot;en&quot;, extensions: %{}, gettext_locale_name: &quot;en&quot;, language: &quot;en&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;en&quot;, requested_locale_name: &quot;en-ES&quot;, script: &quot;Latn&quot;, territory: &quot;ES&quot;, transform: %{}, language_variant: nil }} Matching locales to requested locale names When attempting to match the requested locale name to a configured locale, Cldr attempt to match against a set of reductions in the following order and will return the first match: language, script, territory, variant language, territory, variant language, script, variant language, variant language, script, territory language, territory language, script language requested locale name nil Therefore matching is tolerant of a request for unknown scripts, territories and variants. Only the requested language is a requirement to be matched to a configured locale. Substitutions for Obsolete and Deprecated locale names CLDR provides data to help manage the transition from obsolete or deprecated locale names to current names. For example, the following requests the locale name &quot;mo&quot; which is the deprecated code for &quot;Moldovian&quot;. The replacement code is &quot;ro&quot; (Romanian). iex&gt; Cldr.Locale.new(&quot;mo&quot;, TestBackend.Cldr) {:ok, %Cldr.LanguageTag{extensions: %{}, gettext_locale_name: nil, language: &quot;ro&quot;, language_subtags: [], language_variant: nil, locale: %{}, private_use: [], rbnf_locale_name: &quot;ro&quot;, requested_locale_name: &quot;mo&quot;, script: &quot;Latn&quot;, transform: %{}, canonical_locale_name: &quot;ro-Latn-RO&quot;, cldr_locale_name: &quot;ro&quot;, territory: &quot;RO&quot; }} Likely subtags CLDR also provides data to indetify the most likely subtags for a requested locale name. This data is based on the default content data, the population data, and the the suppress-script data in [BCP47]. It is heuristically derived, and may change over time. For example, when requesting the locale &quot;en&quot;, the following is returned: iex&gt; Cldr.Locale.new(&quot;en&quot;, TestBackend.Cldr) {:ok, %Cldr.LanguageTag{ canonical_locale_name: &quot;en-Latn-US&quot;, cldr_locale_name: &quot;en&quot;, extensions: %{}, gettext_locale_name: &quot;en&quot;, language: &quot;en&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;en&quot;, requested_locale_name: &quot;en&quot;, script: &quot;Latn&quot;, territory: &quot;US&quot;, transform: %{}, language_variant: nil }} Which shows that a the likely subtag for the script is &quot;Latn&quot; and the likely territory is &quot;US&quot;. Using the example for Substitutions above, we can see the result of combining substitutions and likely subtags for locale name &quot;mo&quot; returns the current language code of &quot;ro&quot; as well as the likely territory code of &quot;MD&quot; (Moldova). Unknown territory codes Whilst Cldr is tolerant of invalid territory codes, it is also important that such invalid codes not shadow the potential replacement of deprecated codes nor the insertion of likely subtags. Therefore invalid territory codes are ignored during this process. For example requesting a locale name &quot;en-XX&quot; which requests the invalid territory &quot;XX&quot;, the following will be returned: iex&gt; Cldr.Locale.new(&quot;en-XX&quot;, TestBackend.Cldr) {:ok, %Cldr.LanguageTag{ canonical_locale_name: &quot;en-Latn-US&quot;, cldr_locale_name: &quot;en&quot;, extensions: %{}, gettext_locale_name: &quot;en&quot;, language: &quot;en&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;en&quot;, requested_locale_name: &quot;en&quot;, script: &quot;Latn&quot;, territory: &quot;US&quot;, transform: %{}, language_variant: nil }}"},{"ref":"Cldr.Locale.html#add_likely_subtags/1","title":"Cldr.Locale.add_likely_subtags/1","type":"function","doc":"Replace empty subtags within a Cldr.LanguageTag.t/0 with the most likely subtag. Options language_tag is any language tag returned by Cldr.Locale.new/2 A subtag is called empty if it has a missing script or territory subtag, or it is a base language subtag with the value und. In the description below, a subscript on a subtag x indicates which tag it is from: xs is in the source, xm is in a match, and xr is in the final result. Lookup Lookup each of the following in order, and stops on the first match: languages-scripts-regions languages-regions languages-scripts languages und-scripts Returns If there is no match,either return an error value, or the match for und Otherwise there is a match = languagem-scriptm-regionm Let xr = xs if xs is not empty, and xm otherwise. Return the language tag composed of languager-scriptr-regionr + variants + extensions . Example iex&gt; Cldr.Locale.add_likely_subtags Cldr.LanguageTag.parse!(&quot;zh-SG&quot;) %Cldr.LanguageTag{ canonical_locale_name: nil, cldr_locale_name: nil, language_subtags: [], extensions: %{}, gettext_locale_name: nil, language: &quot;zh&quot;, locale: %{}, private_use: [], rbnf_locale_name: nil, requested_locale_name: &quot;zh-SG&quot;, script: &quot;Hans&quot;, territory: &quot;SG&quot;, transform: %{}, language_variant: nil }"},{"ref":"Cldr.Locale.html#alias_error/2","title":"Cldr.Locale.alias_error/2","type":"function","doc":"Returns an error tuple for an invalid locale alias. Options locale_name is any locale name returned by Cldr.known_locale_names/1"},{"ref":"Cldr.Locale.html#aliases/0","title":"Cldr.Locale.aliases/0","type":"function","doc":"Return a map of the known aliases for Language, Script and Territory"},{"ref":"Cldr.Locale.html#aliases/2","title":"Cldr.Locale.aliases/2","type":"function","doc":"Return a map of the aliases for a given alias key and type Options type is one of [:language, :region, :script, :variant, :zone] key is the substitution key (a language, region, script, variant or zone)"},{"ref":"Cldr.Locale.html#canonical_language_tag/2","title":"Cldr.Locale.canonical_language_tag/2","type":"function","doc":"Parses a locale name and returns a Cldr.LanguageTag struct that represents a locale. Arguments language_tag is any language tag returned by Cldr.Locale.new/2 or any locale_name returned by Cldr.known_locale_names/1 backend is any module that includes use Cldr and therefore is a Cldr backend module Returns {:ok, language_tag} or {:eror, reason} Method The language tag is parsed in accordance with RFC5646 Any language, script or region aliases are replaced. This will replace any obsolete elements with current versions If a territory or script is not specified, a default is provided using the CLDR information returned by Cldr.Locale.likely_subtags/1 A Cldr locale name is selected that is the nearest fit to the requested locale. Example iex&gt; Cldr.Locale.canonical_language_tag(&quot;en&quot;, TestBackend.Cldr) { :ok, %Cldr.LanguageTag{ canonical_locale_name: &quot;en-Latn-US&quot;, cldr_locale_name: &quot;en&quot;, extensions: %{}, gettext_locale_name: &quot;en&quot;, language: &quot;en&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;en&quot;, requested_locale_name: &quot;en&quot;, script: &quot;Latn&quot;, territory: &quot;US&quot;, transform: %{}, language_variant: nil } }"},{"ref":"Cldr.Locale.html#canonical_language_tag!/2","title":"Cldr.Locale.canonical_language_tag!/2","type":"function","doc":"Parses a locale name and returns a Cldr.LanguageTag struct that represents a locale or raises on error. Arguments language_tag is any language tag returned by Cldr.Locale.new/2 or any locale_name returned by Cldr.known_locale_names/1 backend is any module that includes use Cldr and therefore is a Cldr backend module See Cldr.Locale.canonical_language_tag/2 for more information."},{"ref":"Cldr.Locale.html#gettext_locale_error/1","title":"Cldr.Locale.gettext_locale_error/1","type":"function","doc":"Returns an error tuple for an invalid gettext locale. Options locale_name is any locale name returned by Cldr.known_gettext_locale_names/1 Returns {:error, {Cldr.UnknownLocaleError, message}} Examples iex&gt; Cldr.Locale.gettext_locale_error :invalid {Cldr.UnknownLocaleError, &quot;The gettext locale :invalid is not known.&quot;}"},{"ref":"Cldr.Locale.html#likely_subtags/0","title":"Cldr.Locale.likely_subtags/0","type":"function","doc":"Returns the map of likely subtags. Note that not all locales are guaranteed to have likely subtags. Example Cldr.Locale.likely_subtags %{ &quot;bez&quot; =&gt; %Cldr.LanguageTag{ canonical_locale_name: nil, cldr_locale_name: nil, extensions: %{}, language: &quot;bez&quot;, locale: %{}, private_use: [], rbnf_locale_name: nil, requested_locale_name: nil, script: &quot;Latn&quot;, territory: &quot;TZ&quot;, transform: %{}, language_variant: nil }, &quot;fuf&quot; =&gt; %Cldr.LanguageTag{ canonical_locale_name: nil, cldr_locale_name: nil, extensions: %{}, language: &quot;fuf&quot;, locale: %{}, private_use: [], rbnf_locale_name: nil, requested_locale_name: nil, script: &quot;Latn&quot;, territory: &quot;GN&quot;, transform: %{}, language_variant: nil }, ..."},{"ref":"Cldr.Locale.html#likely_subtags/1","title":"Cldr.Locale.likely_subtags/1","type":"function","doc":"Returns the likely substags, as a Cldr.LanguageTag, for a given locale name. Options locale is any valid locale name returned by Cldr.known_locale_names/1 or a Cldr.LanguageTag struct Examples iex&gt; Cldr.Locale.likely_subtags &quot;en&quot; %Cldr.LanguageTag{ canonical_locale_name: nil, cldr_locale_name: nil, extensions: %{}, gettext_locale_name: nil, language: &quot;en&quot;, locale: %{}, private_use: [], rbnf_locale_name: nil, requested_locale_name: &quot;en-Latn-US&quot;, script: &quot;Latn&quot;, territory: &quot;US&quot;, transform: %{}, language_variant: nil }"},{"ref":"Cldr.Locale.html#locale_error/1","title":"Cldr.Locale.locale_error/1","type":"function","doc":"Returns an error tuple for an invalid locale. Arguments locale_name is any locale name returned by Cldr.known_locale_names/1 Returns {:error, {Cldr.UnknownLocaleError, message}} Examples iex&gt; Cldr.Locale.locale_error :invalid {Cldr.UnknownLocaleError, &quot;The locale :invalid is not known.&quot;}"},{"ref":"Cldr.Locale.html#locale_name_from/1","title":"Cldr.Locale.locale_name_from/1","type":"function","doc":"Return a locale name from a Cldr.LanguageTag Options locale_name is any Cldr.LanguageTag struct returned by Cldr.Locale.new!/2 Example iex&gt; Cldr.Locale.locale_name_from Cldr.Locale.new!(&quot;en&quot;, TestBackend.Cldr) &quot;en-Latn-US&quot;"},{"ref":"Cldr.Locale.html#locale_name_from/4","title":"Cldr.Locale.locale_name_from/4","type":"function","doc":"Return a locale name by combining language, script, territory and variant parameters Arguments language, script, territory and variant are string representations, or nil, of the language subtags Returns The locale name constructed from the non-nil arguments joined by a &quot;-&quot; Example iex&gt; Cldr.Locale.locale_name_from(&quot;en&quot;, &quot;Latn&quot;, &quot;001&quot;, nil) &quot;en-Latn-001&quot;"},{"ref":"Cldr.Locale.html#locale_name_from_posix/1","title":"Cldr.Locale.locale_name_from_posix/1","type":"function","doc":"See Cldr.Config.locale_name_from_posix/1."},{"ref":"Cldr.Locale.html#locale_name_to_posix/1","title":"Cldr.Locale.locale_name_to_posix/1","type":"function","doc":"See Cldr.Config.locale_name_to_posix/1."},{"ref":"Cldr.Locale.html#new/2","title":"Cldr.Locale.new/2","type":"function","doc":"See Cldr.Locale.canonical_language_tag/2."},{"ref":"Cldr.Locale.html#new!/2","title":"Cldr.Locale.new!/2","type":"function","doc":"See Cldr.Locale.canonical_language_tag!/2."},{"ref":"Cldr.Locale.html#normalize_locale_name/1","title":"Cldr.Locale.normalize_locale_name/1","type":"function","doc":"Normalize the casing of a locale name. Options locale_name is any valid locale name returned by Cldr.known_locale_names/1 or a Cldr.LanguageTag struct Returns The normalized locale name as a String.t Method Locale names are case insensitive but certain common casing is followed in practise: lower case for a language capital case for a script upper case for a region/territory Note this function is intended to support only the CLDR locale names which have a format that is a subset of the full langauge tag specification. For proper parsing of local names and language tags, see Cldr.Locale.canonical_language_tag/2 Examples iex&gt; Cldr.Locale.normalize_locale_name &quot;zh_hant&quot; &quot;zh-Hant&quot; iex&gt; Cldr.Locale.normalize_locale_name &quot;en_us&quot; &quot;en-US&quot; iex&gt; Cldr.Locale.normalize_locale_name &quot;EN&quot; &quot;en&quot; iex&gt; Cldr.Locale.normalize_locale_name &quot;ca_es_valencia&quot; &quot;ca-ES-VALENCIA&quot;"},{"ref":"Cldr.Locale.html#put_gettext_locale_name/2","title":"Cldr.Locale.put_gettext_locale_name/2","type":"function","doc":""},{"ref":"Cldr.Locale.html#substitute_aliases/1","title":"Cldr.Locale.substitute_aliases/1","type":"function","doc":"Substitute deprectated subtags with a Cldr.LanguageTag with their non-deprecated alternatives. Arguments language_tag is any language tag returned by Cldr.Locale.new/2 Method Replace any deprecated subtags with their canonical values using the alias data. Use the first value in the replacement list, if it exists. Language tag replacements may have multiple parts, such as sh ➞ sr_Latn or mo ➞ ro_MD. In such a case, the original script and/or region/territory are retained if there is one. Thus sh_Arab_AQ ➞ sr_Arab_AQ, not sr_Latn_AQ. Remove the script code &#39;Zzzz&#39; and the territory code &#39;ZZ&#39; if they occur. Get the components of the cleaned-up source tag (languages, scripts, and regions/territories), plus any variants and extensions. Example iex&gt; Cldr.Locale.substitute_aliases Cldr.LanguageTag.Parser.parse!(&quot;mo&quot;) %Cldr.LanguageTag{ canonical_locale_name: nil, cldr_locale_name: nil, extensions: %{}, gettext_locale_name: nil, language: &quot;ro&quot;, language_subtags: [], language_variant: nil, locale: %{}, private_use: [], rbnf_locale_name: nil, requested_locale_name: &quot;mo&quot;, script: nil, transform: %{}, territory: nil }"},{"ref":"Cldr.Locale.html#t:language/0","title":"Cldr.Locale.language/0","type":"type","doc":""},{"ref":"Cldr.Locale.html#t:locale_name/0","title":"Cldr.Locale.locale_name/0","type":"type","doc":"The name of a locale in a string format"},{"ref":"Cldr.Locale.html#t:script/0","title":"Cldr.Locale.script/0","type":"type","doc":""},{"ref":"Cldr.Locale.html#t:subtags/0","title":"Cldr.Locale.subtags/0","type":"type","doc":""},{"ref":"Cldr.Locale.html#t:territory/0","title":"Cldr.Locale.territory/0","type":"type","doc":""},{"ref":"Cldr.Locale.html#t:variant/0","title":"Cldr.Locale.variant/0","type":"type","doc":""},{"ref":"Cldr.NoDefaultBackendError.html","title":"Cldr.NoDefaultBackendError","type":"exception","doc":"Exception raised when there is no default backend configured"},{"ref":"Cldr.NoMatchingLocale.html","title":"Cldr.NoMatchingLocale","type":"exception","doc":"Exception raised when no configured locale matches the provided &quot;Accept-Language&quot; header"},{"ref":"Cldr.Rbnf.NotAvailable.html","title":"Cldr.Rbnf.NotAvailable","type":"exception","doc":"Exception raised when there is no RBNF for a locale."},{"ref":"Cldr.Substitution.html","title":"Cldr.Substitution","type":"module","doc":"Compiles substituation formats that are of the form &quot;{0} something {1}&quot; into a token list that allows for more efficient parameter substituation at runtime."},{"ref":"Cldr.Substitution.html#parse/1","title":"Cldr.Substitution.parse/1","type":"function","doc":"Parses a substitution template into a list of tokens to allow efficient parameter substitution at runtime. template is a binary that may include parameter markers that are substituded for values at runtime. Returns: A list of tokens where any substitution is marked as an integer any any binary tokens are passed through as is. Examples iex&gt; Cldr.Substitution.parse &quot;{0}, {1}&quot; [0, &quot;, &quot;, 1] iex&gt; Cldr.Substitution.parse &quot;{0} This is something {1} or another {2}&quot; [0, &quot; This is something &quot;, 1, &quot; or another &quot;, 2] This function is primarily intended to support compile-time generation of templates that simplify and speed up parameter substitution at runtime."},{"ref":"Cldr.Substitution.html#substitute/2","title":"Cldr.Substitution.substitute/2","type":"function","doc":"Substitutes a list of values into a template token list that is created by Cldr.Substitution.parse/1. list1 is a list of values that will be substituted into a a template list previously created by Cldr.Substitution.parse/1 list2 is a template list previously created by Cldr.Substitution.parse/1 Returns: A list with values substituted for parameters in the list1 template Examples: iex&gt; template = Cldr.Substitution.parse &quot;{0} This is something {1}&quot; [0, &quot; This is something &quot;, 1] iex&gt; Cldr.Substitution.substitute [&quot;a&quot;, &quot;b&quot;], template [&quot;a&quot;, &quot; This is something &quot;, &quot;b&quot;]"},{"ref":"Cldr.UnknownCalendarError.html","title":"Cldr.UnknownCalendarError","type":"exception","doc":"Exception raised when an attempt is made to use a calendar that is not known. in Cldr."},{"ref":"Cldr.UnknownCurrencyError.html","title":"Cldr.UnknownCurrencyError","type":"exception","doc":"Exception raised when there is an invalid currency code."},{"ref":"Cldr.UnknownFormatError.html","title":"Cldr.UnknownFormatError","type":"exception","doc":"Exception raised when an attempt is made to use a locale that is not configured in Cldr. Cldr.known_locale_names/1 returns the locale names known to Cldr."},{"ref":"Cldr.UnknownLocaleError.html","title":"Cldr.UnknownLocaleError","type":"exception","doc":"Exception raised when an attempt is made to use a locale not configured in Cldr. Cldr.known_locale_names/1 returns the locale names known to Cldr."},{"ref":"Cldr.UnknownNumberSystemError.html","title":"Cldr.UnknownNumberSystemError","type":"exception","doc":"Exception raised when an attempt is made to use a number system that is not known in Cldr. Cldr.Number.number_system_names/0 returns the number system names known to Cldr."},{"ref":"Cldr.UnknownNumberSystemTypeError.html","title":"Cldr.UnknownNumberSystemTypeError","type":"exception","doc":"Exception raised when an attempt is made to use a number system type that is not known in Cldr. Cldr.Number.number_system_types/0 returns the number system types known to Cldr."},{"ref":"Cldr.UnknownOTPAppError.html","title":"Cldr.UnknownOTPAppError","type":"exception","doc":"Exception raised when the configured OTP app is not known"},{"ref":"Cldr.UnknownPluralRules.html","title":"Cldr.UnknownPluralRules","type":"exception","doc":"Exception raised when there are no plural rules for a locale or language."},{"ref":"Cldr.UnknownTerritoryError.html","title":"Cldr.UnknownTerritoryError","type":"exception","doc":"Exception raised when there is an invalid territory code."},{"ref":"Cldr.UnknownUnitError.html","title":"Cldr.UnknownUnitError","type":"exception","doc":"Exception raised when an attempt is made to use a unit that is not known. in Cldr."},{"ref":"Cldr.Rbnf.Config.html","title":"Cldr.Rbnf.Config","type":"module","doc":"Rules Base Number Formatting Configuration management. During the process of consolidating the various CLDR files into a standard format that is easily digestible for Cldr, these functions are used to do the parsing and normalising of RBNF data."},{"ref":"Cldr.Rbnf.Config.html#for_locale/1","title":"Cldr.Rbnf.Config.for_locale/1","type":"function","doc":"Returns the rbnf rules for a locale or {:error, :rbnf_file_not_found} locale_name is any locale returned by Rbnf.known_locales/0. Note that for_locale/1 does not raise if the locale does not exist like the majority of Cldr. This is by design since the set of locales that have rbnf rules is substantially less than the set of locales supported by Cldr. Example iex&gt; {:ok, rules} = Cldr.Rbnf.Config.for_locale(&quot;en&quot;) iex&gt; Map.keys(rules) [:OrdinalRules, :SpelloutRules]"},{"ref":"Cldr.Rbnf.Config.html#known_locale_names/1","title":"Cldr.Rbnf.Config.known_locale_names/1","type":"function","doc":"Returns the list of locales that is the intersection of Cldr.known_locale_names/1 and Cldr.Rbnf.rbnf_locales/0 This list is therefore the set of known locales for which there are rbnf rules defined. Example iex&gt; Cldr.Rbnf.Config.known_locale_names [&quot;lo&quot;, &quot;eo&quot;, &quot;ja&quot;, &quot;el&quot;, &quot;fo&quot;, &quot;hu&quot;, &quot;yue&quot;, &quot;fil&quot;, &quot;sq&quot;, &quot;cy&quot;, &quot;da&quot;, &quot;sv&quot;, &quot;ee&quot;, &quot;et&quot;, &quot;ta&quot;, &quot;nl&quot;, &quot;vi&quot;, &quot;nb&quot;, &quot;lv&quot;, &quot;id&quot;, &quot;pt-PT&quot;, &quot;fa-AF&quot;, &quot;lt&quot;, &quot;my&quot;, &quot;sr-Latn&quot;, &quot;cs&quot;, &quot;ms&quot;, &quot;fa&quot;, &quot;bg&quot;, &quot;es&quot;, &quot;en&quot;, &quot;af&quot;, &quot;mt&quot;, &quot;am&quot;, &quot;ca&quot;, &quot;mk&quot;, &quot;ro&quot;, &quot;de-CH&quot;, &quot;ka&quot;, &quot;root&quot;, &quot;hr&quot;, &quot;nn&quot;, &quot;hy&quot;, &quot;pt&quot;, &quot;se&quot;, &quot;he&quot;, &quot;ga&quot;, &quot;sr&quot;, &quot;hi&quot;, &quot;ky&quot;, &quot;ko&quot;, &quot;zh-Hant&quot;, &quot;kl&quot;, &quot;km&quot;, &quot;sk&quot;, &quot;ru&quot;, &quot;zh&quot;, &quot;de&quot;, &quot;fi&quot;, &quot;it&quot;, &quot;be&quot;, &quot;pl&quot;, &quot;az&quot;, &quot;tr&quot;, &quot;is&quot;, &quot;fr-CH&quot;, &quot;es-419&quot;, &quot;th&quot;, &quot;fr-BE&quot;, &quot;fr&quot;, &quot;sl&quot;, &quot;bs&quot;, &quot;uk&quot;, &quot;ar&quot;]"},{"ref":"Cldr.Rbnf.Config.html#rbnf_dir/0","title":"Cldr.Rbnf.Config.rbnf_dir/0","type":"function","doc":"Returns the directory where the RBNF data is stored Example iex&gt; Cldr.Rbnf.Config.rbnf_dir =~ &quot;/cldr-rbnf/rbnf&quot; true"},{"ref":"Cldr.Rbnf.Config.html#rbnf_locale_names/0","title":"Cldr.Rbnf.Config.rbnf_locale_names/0","type":"function","doc":"Returns a list of the locales for which there is an rbnf rule set Relies on the presence of downloaded CLDR data. This function is usefully primarily to a Cldr library developer. Example iex&gt; Cldr.Rbnf.Config.rbnf_locales [&quot;af&quot;, &quot;am&quot;, &quot;ar&quot;, &quot;az&quot;, &quot;be&quot;, &quot;bg&quot;, &quot;bs&quot;, &quot;ca&quot;, &quot;cs&quot;, &quot;cy&quot;, &quot;da&quot;, &quot;de-CH&quot;, &quot;de&quot;, &quot;ee&quot;, &quot;el&quot;, &quot;en&quot;, &quot;eo&quot;, &quot;es-419&quot;, &quot;es&quot;, &quot;et&quot;, &quot;fa-AF&quot;, &quot;fa&quot;, &quot;fi&quot;, &quot;fil&quot;, &quot;fo&quot;, &quot;fr-BE&quot;, &quot;fr-CH&quot;, &quot;fr&quot;, &quot;ga&quot;, &quot;he&quot;, &quot;hi&quot;, &quot;hr&quot;, &quot;hu&quot;, &quot;hy&quot;, &quot;id&quot;, &quot;is&quot;, &quot;it&quot;, &quot;ja&quot;, &quot;ka&quot;, &quot;kl&quot;, &quot;km&quot;, &quot;ko&quot;, &quot;ky&quot;, &quot;lo&quot;, &quot;lt&quot;, &quot;lv&quot;, &quot;mk&quot;, &quot;ms&quot;, &quot;mt&quot;, &quot;my&quot;, &quot;nb&quot;, &quot;nl&quot;, &quot;nn&quot;, &quot;pl&quot;, &quot;pt-PT&quot;, &quot;pt&quot;, &quot;ro&quot;, &quot;root&quot;, &quot;ru&quot;, &quot;se&quot;, &quot;sk&quot;, &quot;sl&quot;, &quot;sq&quot;, &quot;sr-Latn&quot;, &quot;sr&quot;, &quot;sv&quot;, &quot;ta&quot;, &quot;th&quot;, &quot;tr&quot;, &quot;uk&quot;, &quot;vi&quot;, &quot;yue&quot;, &quot;zh-Hant&quot;, &quot;zh&quot;]"},{"ref":"Cldr.LanguageTag.html","title":"Cldr.LanguageTag","type":"module","doc":"Represents a language tag as defined in rfc5646 with extensions &quot;u&quot; and &quot;t&quot; as defined in BCP 47. Language tags are used to help identify languages, whether spoken, written, signed, or otherwise signaled, for the purpose of communication. This includes constructed and artificial languages but excludes languages not intended primarily for human communication, such as programming languages. Syntax A language tag is composed from a sequence of one or more &quot;subtags&quot;, each of which refines or narrows the range of language identified by the overall tag. Subtags, in turn, are a sequence of alphanumeric characters (letters and digits), distinguished and separated from other subtags in a tag by a hyphen (&quot;-&quot;, [Unicode] U+002D). There are different types of subtag, each of which is distinguished by length, position in the tag, and content: each subtag&#39;s type can be recognized solely by these features. This makes it possible to extract and assign some semantic information to the subtags, even if the specific subtag values are not recognized. Thus, a language tag processor need not have a list of valid tags or subtags (that is, a copy of some version of the IANA Language Subtag Registry) in order to perform common searching and matching operations. The only exceptions to this ability to infer meaning from subtag structure are the grandfathered tags listed in the productions &#39;regular&#39; and &#39;irregular&#39; below. These tags were registered under [RFC3066] and are a fixed list that can never change. The syntax of the language tag in ABNF is: Language-Tag = langtag ; normal language tags / privateuse ; private use tag / grandfathered ; grandfathered tags langtag = language [&quot;-&quot; script] [&quot;-&quot; region] *(&quot;-&quot; variant) *(&quot;-&quot; extension) [&quot;-&quot; privateuse] language = 2*3ALPHA ; shortest ISO 639 code [&quot;-&quot; extlang] ; sometimes followed by ; extended language subtags / 4ALPHA ; or reserved for future use / 5*8ALPHA ; or registered language subtag extlang = 3ALPHA ; selected ISO 639 codes *2(&quot;-&quot; 3ALPHA) ; permanently reserved script = 4ALPHA ; ISO 15924 code region = 2ALPHA ; ISO 3166-1 code / 3DIGIT ; UN M.49 code variant = 5*8alphanum ; registered variants / (DIGIT 3alphanum) extension = singleton 1(&quot;-&quot; (28alphanum)) ; Single alphanumerics ; &quot;x&quot; reserved for private use singleton = DIGIT ; 0 - 9 / %x41-57 ; A - W / %x59-5A ; Y - Z / %x61-77 ; a - w / %x79-7A ; y - z privateuse = &quot;x&quot; 1(&quot;-&quot; (18alphanum)) grandfathered = irregular ; non-redundant tags registered / regular ; during the RFC 3066 era irregular = &quot;en-GB-oed&quot; ; irregular tags do not match / &quot;i-ami&quot; ; the &#39;langtag&#39; production and / &quot;i-bnn&quot; ; would not otherwise be / &quot;i-default&quot; ; considered &#39;well-formed&#39; / &quot;i-enochian&quot; ; These tags are all valid, / &quot;i-hak&quot; ; but most are deprecated / &quot;i-klingon&quot; ; in favor of more modern / &quot;i-lux&quot; ; subtags or subtag / &quot;i-mingo&quot; ; combination / &quot;i-navajo&quot; / &quot;i-pwn&quot; / &quot;i-tao&quot; / &quot;i-tay&quot; / &quot;i-tsu&quot; / &quot;sgn-BE-FR&quot; / &quot;sgn-BE-NL&quot; / &quot;sgn-CH-DE&quot; regular = &quot;art-lojban&quot; ; these tags match the &#39;langtag&#39; / &quot;cel-gaulish&quot; ; production, but their subtags / &quot;no-bok&quot; ; are not extended language / &quot;no-nyn&quot; ; or variant subtags: their meaning / &quot;zh-guoyu&quot; ; is defined by their registration / &quot;zh-hakka&quot; ; and all of these are deprecated / &quot;zh-min&quot; ; in favor of a more modern / &quot;zh-min-nan&quot; ; subtag or sequence of subtags / &quot;zh-xiang&quot; alphanum = (ALPHA / DIGIT) ; letters and numbers All subtags have a maximum length of eight characters. Whitespace is not permitted in a language tag. There is a subtlety in the ABNF production &#39;variant&#39;: a variant starting with a digit has a minimum length of four characters, while those starting with a letter have a minimum length of five characters. Unicode BCP 47 Extension type &quot;u&quot; - Locale ExtensionDescriptionExamples +-------+---------------------------------------- caCalendar typebuddhist, chinese, gregory cfCurrency format stylestandard, account coCollation typestandard, search, phonetic, pinyin cuCurrency typeISO4217 code like &quot;USD&quot;, &quot;EUR&quot; fwFirst day of the week identifiersun, mon, tue, wed, ... hcHour cycle identifierh12, h23, h11, h24 lbLine break style identifierstrict, normal, loose lwWord break identifiernormal, breakall, keepall msMeasurement system identifiermetric, ussystem, uksystem nuNumber system identifierarabext, armnlow, roman, tamldec rgRegion overrideThe value is a unicode_region_subtag for a regular region (not a macroregion), suffixed by &quot;ZZZZ&quot; sdSubdivision identifierA unicode_subdivision_id, which is a unicode_region_subtagconcatenated with a unicode_subdivision_suffix. ssBreak supressions identifiernone, standard tzTimezone identifierShort identifiers defined in terms of a TZ time zone database vaCommon variant typePOSIX style locale variant Unicode BCP 47 Extension type &quot;t&quot; - Transforms ExtensionDescription +-------+----------------------------------------- moTransform extension mechanism: to reference an authority or rules for a type of transformation s0Transform source: for non-languages/scripts, such as fullwidth-halfwidth conversion. d0Transform sdestination: for non-languages/scripts, such as fullwidth-halfwidth conversion. i0Input Method Engine transform k0Keyboard transform t0Machine Translation: Used to indicate content that has been machine translated h0Hybrid Locale Identifiers: h0 with the value &#39;hybrid&#39; indicates that the -t- value is a language that is mixed into the main language tag to form a hybrid x0Private use transform Extensions are formatted by specifying keyword pairs after an extension separator. The example de-DE-u-co-phonebk specifies German as spoken in Germany with a collation of phonebk. Another example, &quot;en-latn-AU-u-cf-account&quot; represents English as spoken in Australia, with the number system &quot;latn&quot; but formatting currencies with the &quot;accounting&quot; style."},{"ref":"Cldr.LanguageTag.html#parse/1","title":"Cldr.LanguageTag.parse/1","type":"function","doc":"Parse a locale name into a Cldr.LangaugeTag struct. locale_name is any valid locale name returned by Cldr.known_locale_names/1 Returns: {:ok, language_tag} or {:error, reason}"},{"ref":"Cldr.LanguageTag.html#parse!/1","title":"Cldr.LanguageTag.parse!/1","type":"function","doc":"Parse a locale name into a Cldr.LangaugeTag struct and raises on error Arguments locale_name is any valid locale name returned by Cldr.known_locale_names/1 Returns: language_tag or raises an exception"},{"ref":"Cldr.LanguageTag.html#to_string/1","title":"Cldr.LanguageTag.to_string/1","type":"function","doc":"Reconstitute a textual language tag from a LanguageTag that is suitable to pass to a collator. Example iex&gt; {:ok, locale} = Cldr.validate_locale &quot;en-US-u-co-phonebk-nu-arab&quot;, MyApp.Cldr iex&gt; Cldr.LanguageTag.to_string(locale) &quot;en-Latn-US-u-co-phonebk-nu-arab&quot;"},{"ref":"Cldr.LanguageTag.html#t:t/0","title":"Cldr.LanguageTag.t/0","type":"type","doc":""},{"ref":"Cldr.LanguageTag.ParseError.html","title":"Cldr.LanguageTag.ParseError","type":"exception","doc":"Exception raised when a language tag cannot be parsed (there is unparsed content)."},{"ref":"Cldr.LanguageTag.Parser.html","title":"Cldr.LanguageTag.Parser","type":"module","doc":"Parses a CLDR language tag (also referred to as locale string). The applicable specification is from CLDR which is similar based upon RFC5646 with some variations."},{"ref":"Cldr.LanguageTag.Parser.html#parse/1","title":"Cldr.LanguageTag.Parser.parse/1","type":"function","doc":"Parse a locale name into a Cldr.LanguageTag.t/0 locale_name is a string representation of a language tag as defined by RFC5646 Returns {:ok, language_tag} or {:error, reasons}"},{"ref":"Cldr.LanguageTag.Parser.html#parse!/1","title":"Cldr.LanguageTag.Parser.parse!/1","type":"function","doc":"Parse a locale name into a Cldr.LanguageTag.t/0 locale_name is a string representation of a language tag as defined by RFC5646 Returns language_tag or raises an exception"},{"ref":"Cldr.Plug.AcceptLanguage.html","title":"Cldr.Plug.AcceptLanguage","type":"module","doc":"Parses the accept-language header if one is available and sets conn.private[:cldr_locale] accordingly. The locale can be later retrieved by Cldr.Plug.AcceptLanguage.get_cldr_locale/1 Example plug Cldr.Plug.AcceptLanguage, cldr_backend: MyApp.Cldr"},{"ref":"Cldr.Plug.AcceptLanguage.html#best_match/2","title":"Cldr.Plug.AcceptLanguage.best_match/2","type":"function","doc":"Returns the locale which is the best match for the provided accept-language header"},{"ref":"Cldr.Plug.AcceptLanguage.html#get_cldr_locale/1","title":"Cldr.Plug.AcceptLanguage.get_cldr_locale/1","type":"function","doc":"Return the locale set by Cldr.Plug.AcceptLanguage"},{"ref":"Cldr.Plug.SetLocale.html","title":"Cldr.Plug.SetLocale","type":"module","doc":"Sets the Cldr and/or Gettext locales derived from the accept-language header, a query parameter, a url parameter, a body parameter or the session. Options :apps - list of apps for which to set locale. See the apps configuration section. :from - where in the request to look for the locale. The default is [:session, :accept_language]. The valid options are: :accept_language will parse the accept-language header and finds the best matched configured locale :path will look for a locale by examining conn.path_params :query will look for a locale by examining conn.query_params :body will look for a locale by examining conn.body_params :cookie will look for a locale in the request cookie(s) :session will look for a locale in the session :default - the default locale to set if no locale is found by other configured methods. It can be a string like &quot;en&quot; or a Cldr.LanguageTag struct. The default is Cldr.default_locale/1 :gettext - the name of the Gettext backend module upon which the locale will be validated. This option is not required if a gettext module is specified in the :apps configuration. :cldr - the name of the Cldr backend module upon which the locale will be validated. This option is not required if a gettext module is specified in the :apps configuration. :session_key - defines the key used to look for the locale in the session. The default is locale. If a locale is found then conn.private[:cldr_locale] is also set. It can be retrieved with Cldr.Plug.SetLocale.get_cldr_locale/1. App configuration The :apps configuration key defines which applications will have their locale set by this plug. Cldr.Plug.SetLocale can set the locale for cldr, gettext or both. The basic configuration of the :app key is an atom, or list of atoms, containing one or both of these app names. For example: apps: :cldr apps: :gettext apps: [:cldr, :gettext] In each of these cases, the locale is set globally for the current process. Sometimes setting the locale for only a specific backend is required. In this case, configure the :apps key as a keyword list pairing an application with the required backend module. The value :global signifies setting the local for the global context. For example: apps: [cldr: MyApp.Cldr] apps: [gettext: MyAppGettext] apps: [gettext: :global] apps: [cldr: MyApp.Cldr, gettext: MyAppGettext] Examples # Will set the global locale for the current process # for both `:cldr` and `:gettext` plug Cldr.Plug.SetLocale, apps: [:cldr, :gettext], from: [:query, :path, :body, :cookie, :accept_language], param: &quot;locale&quot;, gettext: GetTextModule, cldr: MyApp.Cldr session_key: &quot;cldr_locale&quot; # Will set the backend only locale for the current process # for both `:cldr` and `:gettext` plug Cldr.Plug.SetLocale, apps: [cldr: MyApp.Cldr, gettext: GetTextModule], from: [:query, :path, :body, :cookie, :accept_language], param: &quot;locale&quot;, session_key: &quot;cldr_locale&quot; # Will set the backend only locale for the current process # for `:cldr` and globally for `:gettext` plug Cldr.Plug.SetLocale, apps: [cldr: MyApp.Cldr, gettext: :global], from: [:query, :path, :body, :cookie, :accept_language], param: &quot;locale&quot;, session_key: &quot;cldr_locale&quot;"},{"ref":"Cldr.Plug.SetLocale.html#get_cldr_locale/1","title":"Cldr.Plug.SetLocale.get_cldr_locale/1","type":"function","doc":"Return the locale set by Cldr.Plug.SetLocale"},{"ref":"MyApp.Gettext.html","title":"MyApp.Gettext","type":"module","doc":""},{"ref":"MyApp.Gettext.html#dgettext/3","title":"MyApp.Gettext.dgettext/3","type":"macro","doc":""},{"ref":"MyApp.Gettext.html#dgettext_noop/2","title":"MyApp.Gettext.dgettext_noop/2","type":"macro","doc":""},{"ref":"MyApp.Gettext.html#dngettext/5","title":"MyApp.Gettext.dngettext/5","type":"macro","doc":""},{"ref":"MyApp.Gettext.html#dngettext_noop/3","title":"MyApp.Gettext.dngettext_noop/3","type":"macro","doc":""},{"ref":"MyApp.Gettext.html#gettext/2","title":"MyApp.Gettext.gettext/2","type":"macro","doc":""},{"ref":"MyApp.Gettext.html#gettext_comment/1","title":"MyApp.Gettext.gettext_comment/1","type":"macro","doc":""},{"ref":"MyApp.Gettext.html#gettext_noop/1","title":"MyApp.Gettext.gettext_noop/1","type":"macro","doc":""},{"ref":"MyApp.Gettext.html#handle_missing_bindings/2","title":"MyApp.Gettext.handle_missing_bindings/2","type":"function","doc":"Default handling for missing bindings. This function is called when there are missing bindings in a translation. It takes a Gettext.MissingBindingsError struct and the translation with the wrong bindings left as is with the %{} syntax. For example, if something like this is called: MyApp.Gettext.gettext(&quot;Hello %{name}, welcome to %{country}&quot;, name: &quot;Jane&quot;, country: &quot;Italy&quot;) and our it/LC_MESSAGES/default.po looks like this: msgid &quot;Hello %{name}, welcome to %{country}&quot; msgstr &quot;Ciao %{name}, benvenuto in %{cowntry}&quot; # (typo) then Gettext will call: MyApp.Gettext.handle_missing_bindings(exception, &quot;Ciao Jane, benvenuto in %{cowntry}&quot;) where exception is a struct that looks like this: %Gettext.MissingBindingsError{ backend: MyApp.Gettext, domain: &quot;default&quot;, locale: &quot;it&quot;, msgid: &quot;Hello %{name}, welcome to %{country}&quot;, bindings: [:country], } The return value of the c:handle_missing_bindings/2 callback is used as the translated string that the translation macros and functions return. The default implementation for this function uses Logger.error/1 to warn about the missing binding and returns the translated message with the incomplete bindings. This function can be overridden. For example, to raise when there are missing bindings: def handle_missing_bindings(exception, _incomplete) do raise exception end Callback implementation for Gettext.Backend.handle_missing_bindings/2."},{"ref":"MyApp.Gettext.html#handle_missing_plural_translation/6","title":"MyApp.Gettext.handle_missing_plural_translation/6","type":"function","doc":"Default handling for plural translations with a missing translation. Same as c:handle_missing_translation/4, but for plural translations. In this case, n is the number used for pluralizing the translated string. Callback implementation for Gettext.Backend.handle_missing_plural_translation/6."},{"ref":"MyApp.Gettext.html#handle_missing_translation/4","title":"MyApp.Gettext.handle_missing_translation/4","type":"function","doc":"Default handling for translations with a missing translation. When a Gettext function/macro is called with a string to translate into a locale but that locale doesn&#39;t provide a translation for that string, this callback is invoked. msgid is the string that Gettext tried to translate. This function should return {:ok, translated} if a translation can be fetched or constructed for the given string, or {:default, msgid} otherwise. Callback implementation for Gettext.Backend.handle_missing_translation/4."},{"ref":"MyApp.Gettext.html#lgettext/4","title":"MyApp.Gettext.lgettext/4","type":"function","doc":""},{"ref":"MyApp.Gettext.html#lngettext/6","title":"MyApp.Gettext.lngettext/6","type":"function","doc":""},{"ref":"MyApp.Gettext.html#ngettext/4","title":"MyApp.Gettext.ngettext/4","type":"macro","doc":""},{"ref":"MyApp.Gettext.html#ngettext_noop/2","title":"MyApp.Gettext.ngettext_noop/2","type":"macro","doc":""},{"ref":"readme.html","title":"Getting Started with Cldr 2.0","type":"extras","doc":"Getting Started with Cldr 2.0"},{"ref":"readme.html#getting-started","title":"Getting Started with Cldr 2.0 - Getting Started","type":"extras","doc":"Cldr is an Elixir library for the Unicode Consortium&#39;s Common Locale Data Repository (CLDR). The intentions of CLDR, and this library, is to simplify the locale specific formatting of numbers, lists, currencies, calendars, units of measure and dates/times. As of April 22nd, 2019 and ex_cldr Version 2.11.0, Cldr is based upon CLDR version 36.0.0. The first step is to define a module that will host the desired Cldr configuration and the functions that serve as the public API. This module is referred to in this documentation as a backend module. For example: @doc &quot;&quot;&quot; Define a backend module that will host our Cldr configuration and public API. Most function calls in Cldr will be calls to functions on this module. &quot;&quot;&quot; defmodule MyApp.Cldr do use Cldr, locales: [&quot;en&quot;, &quot;fr&quot;, &quot;zh&quot;, &quot;th&quot;], default_locale: &quot;en&quot; end This strategy means that different configurations can be defined and it also means that one Cldr implementation won&#39;t interfer with implementations in other, potentially dependent, applications. The functions you are mostly likely to use are: MyApp.Cldr.default_locale/0 MyApp.Cldr.put_locale/1 MyApp.Cldr.get_locale/0 MyApp.Cldr.known_locale_names/0 MyApp.Cldr.Locale.new/1 To access the raw Cldr data for a locale the Cldr.Config module is available. Note that the functions in Cldr.Config are typically used by library authors. The most useful function is: Cldr.Config.get_locale/2 which returns a map of all the CLDR data known to Cldr. Since this data is read from a file, parsed and then formatted it is a function that should be used with care due to the material performance implications. Cldr uses this function during compilation to build functions that return the relevant data with higher performance and these functions are to be preferred over the use of Cldr.Config.get_locale/2."},{"ref":"readme.html#use-this-package-when-you-have-a-requirement-to","title":"Getting Started with Cldr 2.0 - Use this package when you have a requirement to...","type":"extras","doc":"Support multiple languages and locales in your application Need to support formatting numbers, dates, times, date-times, SI units and lists in one language or many Access the data maintained in the CLDR repository in a functional manner Parse an Accept-Language http header or a language tag It is highly likely that you will also want to install one or more of the dependent packages that provide localization and formatting for a particular data domain. See Additional Cldr Packages below."},{"ref":"readme.html#elixir-version-requirements","title":"Getting Started with Cldr 2.0 - Elixir Version Requirements","type":"extras","doc":"ex_cldr requires Elixir 1.5 or later."},{"ref":"readme.html#installation","title":"Getting Started with Cldr 2.0 - Installation","type":"extras","doc":"Add ex_cldr and the JSON library of your choice as a dependencies to your mix project: defp deps do [ {:ex_cldr, &quot;~&gt; 2.0&quot;}, # Posion or any other compatible json library # that implements `encode!/1` and `decode!/1` # :jason is recommended {:jason, &quot;~&gt; 1.0&quot;} # {:poison, &quot;~&gt; 2.1 or ~&gt; 3.0&quot;} ] end then retrieve ex_cldr and the JSON library from hex: mix deps.get mix deps.compile"},{"ref":"readme.html#additional-cldr-packages","title":"Getting Started with Cldr 2.0 - Additional Cldr Packages","type":"extras","doc":"ex_cldr includes only basic functions to maintain the CLDR data repository in an accessible manner and to manage locale definitions. Additional functionality is available by adding additional packages: Number formatting: ex_cldr_numbers List formatting: ex_cldr_lists Unit formatting: ex_cldr_units Date/Time/DateTime formatting: ex_cldr_dates_times Calendars: ex_cldr_calendars Calendar formatting: ex_cldr_calendars_format Printf-like formatting: ex_cldr_print Collation: ex_cldr_collation ICU Message formatting: ex_cldr_messages Territories localization and information: ex_cldr_territories by @Schultzer Languages localization: ex_cldr_languages by @lostkobrakai Each of these packages includes ex_cldr as a dependency so configuring any of these additional packages will automatically install ex_cldr."},{"ref":"readme.html#configuration","title":"Getting Started with Cldr 2.0 - Configuration","type":"extras","doc":"Cldr attempts to maximise runtime performance at the expense of additional compile time. Where possible Cldr will create functions to encapsulate data at compile time. To perform these optimizations for all 541 locales known to Cldr wouldn&#39;t be an effective use of your time or your computer&#39;s. Therefore Cldr requires that you configure the locales you want to use. The preferred way to configure Cldr is to define the configuration in your backend module. This removes any dependency on your mix.exs and therefore simplifies deployment as a release. However configuration can also be defined in other ways: Global configuration. In mix.exs a global configuration can be defined under the :ex_cldr key. Although any valid configuration keys can be used here, only the keys :json_library and default_locale are considered valid. Other configuration keys may be used to aid migration from Cldr version 1.x but a deprecation message will be printed during compilation. Here&#39;s an example of global configuration: config :ex_cldr, default_locale: &quot;en&quot;, json_library: Jason, Note that the :json_library key can only be defined at the global level since it is required during compilation before any backend module is compiled. Global configuration most closely approximates the configuration methods in Cldr version 1.x and therefore remains supported to ease migration only. If configuration beyond the keys :default_locale or :json_library are defined a deprecation warning is printed at compile time noting that configuration should be moved to a backend module. Backend Module Configuration The preferred configuration method is to define the configuration in the backend module. The configuration keys are the same so the preferred way to achieve the same configuration as defined in the global example is: defmodule MyApp.Cldr do use Cldr, default_locale: &quot;en&quot;, locales: [&quot;fr&quot;, &quot;en&quot;, &quot;bs&quot;, &quot;si&quot;, &quot;ak&quot;, &quot;th&quot;], gettext: MyApp.Gettext, data_dir: &quot;./priv/cldr&quot;, otp_app: :my_app, precompile_number_formats: [&quot;¤¤#,##0.##&quot;], precompile_transliterations: [{:latn, :arab}, {:thai, :latn}], providers: [Cldr.Number], generate_docs: true end Otp App Configuration In the backend configuration example above the :otp_app key has been defined. This means that conifguration for Cldr has been defined in mix.exs under the key :my_app with the sub-key MyApp.Cldr. For example: defmodule MyApp.Cldr do use Cldr, otp_app: :my_app end # In mix.exs config :my_app, MyApp.Cldr, default_locale: &quot;en&quot;, locales: [&quot;fr&quot;, &quot;en&quot;, &quot;bs&quot;, &quot;si&quot;, &quot;ak&quot;, &quot;th&quot;], gettext: MyApp.Gettext, data_dir: &quot;./priv/cldr&quot;, precompile_number_formats: [&quot;¤¤#,##0.##&quot;], precompile_transliterations: [{:latn, :arab}, {:thai, :latn}] Multiple backends can be configured under a single :otp_app if required. Configuration Priority When building the consolidated configuration the following priority applies: Consider the global configuration Merge the otp_app configuration over the top of the global configuration Merge the backend module configuration over the top Configuration Keys The configuration keys available for Cldr are: default_locale specifies the default locale to be used for this backend. The default locale in case no other locale has been set is &quot;en-001&quot;. The default locale calculated as follows: If set by the :default_locale key, then this is the priority If no :default_locale key, then a configured Gettext default locale for this backend is chosen If no :default_locale key is specified and no Gettext module is configured, or is configured but has no default set, use Cldr.default_locale/0 which returns either the default locale configurated in mix.exs under the ex_cldr key or then the system default locale will is currently en-001 locales: Defines what locales will be configured in Cldr. Only these locales will be available and an exception Cldr.UnknownLocaleError will be raised if there is an attempt to use an unknown locale. This is the same behaviour as Gettext. Locales are configured as a list of binaries (strings). For convenince it is possible to use wildcard matching of locales which is particulalry helpful when there are many regional variances of a single language locale. For example, there are over 100 regional variants of the &quot;en&quot; locale in CLDR. A wildcard locale is detected by the presence of ., [, * and + in the locale string. This locale is then matched using the pattern as a regex to match against all available locales. The example below will configure all locales that start with en- and the locale fr. use Cldr, default_locale: &quot;en&quot;, locales: [&quot;en-*&quot;, &quot;fr&quot;] There is one additional setting which is :all which will configure all 541 locales. This is highly discouraged since it will take many minutes to compile your project and will consume more memory than you really want. This setting is there to aid in running the test suite. Really, don&#39;t use this setting. :gettext: configures Cldr to use a Gettext module as an additional source of locales you want to configure. Since Gettext uses the Posix locale name format (locales with an &#39;_&#39; in them) and Cldr uses the Unicode format (a &#39;-&#39; as the subtag separator), Cldr will transliterate locale names from Gettext into the Cldr canonical form. :data_dir: indicates where downloaded locale files will be stored. The default is :code.priv_dir(otp_app) where otp_app is the app defined under the :otp_app configuration key. If that key is not specified then the :ex_cldr app is used. It is recommended that an :otp_app key is specified in your backend module configuration. :precompile_number_formats: provides a means to have user-defined format strings precompiled at application compile time. This has a performance benefit since precompiled formats execute approximately twice as fast as formats that are not precompiled. :precompile_transliterations: defines those transliterations between the digits of two different number systems that will be precompiled. The is a list of 2-tuples where each tuple is of the form {from_number_system, to_number_system} where each number system is expressed as an atom. The available number systems is returned by Cldr.Number.System.systems_with_digits/0. The default is the empty list []. :providers: a list of modules that provide Cldr functionality to be compiled into the backend module. See the providers section below. :json_library: Configures the json library to be used for decoding the locale definition files. The default is Jason if available then Poison if not. Any library that provides the functions encode!/1 and decode!/1 can be used. This key can only be specified in the global configuration in mix.exs. Since the json library is configurable it will also need to be configured in the project&#39;s mix.exs. :generate_docs defines whether or not to generate documentation for the modules built as part of the backend. Since these modules represent the public API for ex_cldr, the default is true. Setting this key to false (the atom false, not a falsy value) which prevent the generation of docs for this backend. :supress_warnings defines whether warnings are logged when a provider module is configured but not available. It also controls whether warnings are logged when a number format is compiled at runtime. Its purpose is to help identify those formats which might best be added to the :precompile_number_formats configuration. The default is false. Warning are not logged when set to true. Providers The data maintained by CLDR is quite large and not all capabilities are required by all applications. Hence Cldr has additional optional functionality that can be provided through additional hex packages. In order to support compile-time additions to a configured backend, any package can define a provider that will be called at compile time. The currently known providers and their hex package names are: Hex PackageProvider ModuleComment ex_cldr_numbersCldr.NumberFormatting of numbers, currencies ex_cldr_listsCldr.ListFormatting of lists ex_cldr_unitsCldr.UnitFormatting of SI and Imperial units ex_cldr_territoriesCldr.TerritoryFormatting of territory (country) data ex_cldr_languagesCldr.LanguageFormatting of language information ex_cldr_dates_timesCldr.DateTimeFormatting of dates, times &amp; datetimes ex_moneyMoneyOperations and formatting of a money type ex_messagesCldr.MessageFormatting of ICU-formatted messages Any library author can create a provider module by exposing a function called cldr_backend_provider/1 that takes a Cldr.Config struct as a single parameter. The function should return an AST that is inserted into the backend module being compiled. Providers are configured on each backend module under the :providers key. It must be a list of provider modules. For example: defmodule MyApp.Cldr do use Cldr, locales: [&quot;en&quot;, &quot;zh&quot;], default_locale: &quot;en&quot;, providers: [Cldr.Number, Cldr.List] end If :providers is nil (the default), Cldr will attempt to configure all of the providers described above if they have been installed as deps. If you don&#39;t wish to invoke any providers, use the empty list []."},{"ref":"readme.html#migrating-from-cldr-1-x","title":"Getting Started with Cldr 2.0 - Migrating from Cldr 1.x","type":"extras","doc":"Create a backend module by following the configuration instructions Delete any duplicated global configuration in any config.exs files. Only the keys :default_locale and :json_library are supported in the global configuration Update any plugs to configure the desired backend Adjust any API calls from Cldr.some_function to MyApp.Cldr.some_function. Or better still, alias your backend module where required. ie. alias MyApp.Cldr, as: Cldr"},{"ref":"readme.html#downloading-configured-locales","title":"Getting Started with Cldr 2.0 - Downloading Configured Locales","type":"extras","doc":"Cldr can be installed from either github or from hex. If installed from github then all 541 locales are installed when the repo is cloned into your application deps. If installed from hex then only the locales &quot;en&quot;, &quot;en-001&quot; and &quot;root&quot; are installed. When you configure additional locales these will be downloaded during application compilation."},{"ref":"readme.html#localizing-and-formatting-numbers","title":"Getting Started with Cldr 2.0 - Localizing and Formatting Numbers","type":"extras","doc":"The Cldr.Number module implemented in the ex_cldr_numbers package provides number formatting. The public API for number formatting is MyApp.Cldr.Number.to_string/2. Some examples: iex&gt; MyApp.Cldr.Number.to_string 12345 &quot;12,345&quot; iex&gt; MyApp.Cldr.Number.to_string 12345, locale: &quot;fr&quot; &quot;12 345&quot; iex&gt; MyApp.Cldr.Number.to_string 12345, locale: &quot;fr&quot;, currency: &quot;USD&quot; &quot;12 345,00 $US&quot; iex&gt; MyApp.Cldr.Number.to_string 12345, format: &quot;#E0&quot; &quot;1.2345E4&quot; iex(&gt; MyApp.Cldr.Number.to_string 1234, format: :roman &quot;MCCXXXIV&quot; iex&gt; MyApp.Cldr.Number.to_string 1234, format: :ordinal &quot;1,234th&quot; iex&gt; MyApp.Cldr.Number.to_string 1234, format: :spellout &quot;one thousand two hundred thirty-four&quot; See h MyApp.Cldr.Number and h MyApp.Cldr.Number.to_string in iex for further information."},{"ref":"readme.html#localizing-lists","title":"Getting Started with Cldr 2.0 - Localizing Lists","type":"extras","doc":"The Cldr.List module provides list formatting and is implemented in the ex_cldr_lists package. The public API for list formating is Cldr.List.to_string/2. Some examples: iex&gt; MyApp.Cldr.List.to_string([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;], locale: &quot;en&quot;) &quot;a, b, and c&quot; iex&gt; MyApp.Cldr.List.to_string([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;], locale: &quot;en&quot;, format: :unit_narrow) &quot;a b c&quot; iex&gt; MyApp.Cldr.List.to_string([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;], locale: &quot;fr&quot;) &quot;a, b et c&quot; See h MyApp.Cldr.List and h MyApp.Cldr.List.to_string in iex for further information."},{"ref":"readme.html#localizing-units","title":"Getting Started with Cldr 2.0 - Localizing Units","type":"extras","doc":"The Cldr.Unit module provides unit localization and is implemented in the ex_cldr_units package. The public API for unit localization is Cldr.Unit.to_string/3. Some examples: iex&gt; MyApp.Cldr.Unit.to_string 123, :gallon &quot;123 gallons&quot; iex&gt; MyApp.Cldr.Unit.to_string 1234, :gallon, format: :long &quot;1 thousand gallons&quot; iex&gt; MyApp.Cldr.Unit.to_string 1234, :gallon, format: :short &quot;1K gallons&quot; iex&gt; MyApp.Cldr.Unit.to_string 1234, :megahertz &quot;1,234 megahertz&quot; iex&gt; MyApp.Cldr.Unit.available_units [:acre, :acre_foot, :ampere, :arc_minute, :arc_second, :astronomical_unit, :bit, :bushel, :byte, :calorie, :carat, :celsius, :centiliter, :centimeter, :century, :cubic_centimeter, :cubic_foot, :cubic_inch, :cubic_kilometer, :cubic_meter, :cubic_mile, :cubic_yard, :cup, :cup_metric, :day, :deciliter, :decimeter, :degree, :fahrenheit, :fathom, :fluid_ounce, :foodcalorie, :foot, :furlong, :g_force, :gallon, :gallon_imperial, :generic, :gigabit, :gigabyte, :gigahertz, :gigawatt, :gram, :hectare, :hectoliter, :hectopascal, :hertz, :horsepower, :hour, :inch, ...] See h MyApp.Cldr.Unit and h MyApp.Cldr.Unit.to_string in iex for further information."},{"ref":"readme.html#localizing-dates-times-and-datetimes","title":"Getting Started with Cldr 2.0 - Localizing Dates, Times and DateTimes","type":"extras","doc":"Formatting of relative dates and date times is supported in the Cldr.DateTime.Relative module implemented in the ex_cldr_dates_times package. The public API is MyApp.Cldr.DateTime.to_string/2 and MyApp.Cldr.DateTime.Relative.to_string/2. Some examples: iex&gt; MyApp.Cldr.Date.to_string Date.utc_today() {:ok, &quot;Aug 18, 2017&quot;} iex&gt; MyApp.Cldr.Time.to_string Time.utc_now {:ok, &quot;11:38:55 AM&quot;} iex&gt; MyApp.Cldr.DateTime.to_string DateTime.utc_now {:ok, &quot;Aug 18, 2017, 11:39:08 AM&quot;} iex&gt; MyApp.Cldr.DateTime.Relative.to_string 1, unit: :day, format: :narrow {:ok, &quot;tomorrow&quot;} iex&gt; MyApp.Cldr.DateTime.Relative.to_string(1, unit: :day, locale: &quot;fr&quot;) &quot;demain&quot; iex&gt; MyApp.Cldr.DateTime.Relative.to_string(1, unit: :day, format: :narrow) &quot;tomorrow&quot; iex&gt; MyApp.Cldr.DateTime.Relative.to_string(1234, unit: :year) &quot;in 1,234 years&quot; iex&gt; MyApp.Cldr.DateTime.Relative.to_string(1234, unit: :year, locale: &quot;fr&quot;) &quot;dans 1 234 ans&quot;"},{"ref":"readme.html#gettext-backend-pluralization-support","title":"Getting Started with Cldr 2.0 - Gettext Backend Pluralization Support","type":"extras","doc":"There is an experimental plurals module for Gettext called Cldr.Gettext.Plural. It is configured in Gettext by: defmodule MyApp.Gettext do use Gettext, plural_forms: Cldr.Gettext.Plural end Cldr.Gettext.Plural will fall back to Gettext pluralisation if the locale is not known to Cldr. This module is only compiled if Gettext is configured as a dependency in your project. Note that Cldr.Gettext.Plural does not guarantee to return the same plural index as Gettext&#39;s own pluralization engine which can introduce some compatibility issues if you plan to mix plural engines."},{"ref":"readme.html#plugs","title":"Getting Started with Cldr 2.0 - Plugs","type":"extras","doc":"Cldr provides two plugs to aid integration into an HTTP workflow. These two plugs are: Cldr.Plug.AcceptLanguage which will parse an accept-language header and resolve the best matched and configured Cldr locale. The result is stored in conn.private[:cldr_locale] which is also returned by Cldr.Plug.AcceptLanguage.get_cldr_locale/1. Cldr.Plug.SetLocale which will look for a locale in the several places and then call Cldr.put_locale/2 and Gettext.put_locale/2 if configured so to do. Finally, The result is stored in conn.private[:cldr_locale] which is then available through Cldr.Plug.SetLocale.get_cldr_locale/1. The plug will look for a locale in the following locations depending on the plug configuration: path_params query_params body_params cookies accept-language header the session See Cldr.Plug.SetLocale for a description of how to configure the plug. In addition, note that when migrating from ex_cldr 1.x versions, a backend needs to be configured for both plugs. In the simplest case an example would be: plug Cldr.Plug.SetLocale, apps: [:cldr], cldr: MyApp.Cldr plug Cldr.Plug.AcceptLanguage, cldr_backend: MyApp.Cldr"},{"ref":"readme.html#about-language-tags-and-locale-strings","title":"Getting Started with Cldr 2.0 - About Language Tags and Locale strings","type":"extras","doc":"Note that Cldr defines locale strings according to the IETF standard as defined in RFC5646. Cldr also implements the u extension as defined in RFC6067 and the t extension defined in RFC6497. This is also the standard used by W3C. The IETF standard is slightly different to the ISO/IEC 15897 standard used by Posix-based systems; primarily in that ISO 15897 uses a &quot;_&quot; separator whereas IETF and W3C use &quot;-&quot;. Locale string are case insensitive but there are common conventions: Language codes are lower-cased Territory codes are upper-cased Script names are capital-cased Notes A language code is an ISO3166 language code. Potentially one or more modifiers separated by - (dash), not a _. (underscore). If you configure a Gettext module then Cldr will transliterate Gettext&#39;s _ into - for compatibility. Typically the modifier is a territory code. This is commonly a two-letter uppercase combination. For example pt-PT is the locale referring to Portugese as used in Portugal. In Cldr a locale name is always a binary and never an atom. Internally a locale is parsed and stored as a Cldr.LanguageTag struct. The locales known to Cldr can be retrieved by Cldr.known_locale_names/1 to get the locales known to this configuration of Cldr and Cldr.all_locale_names/0 to get the locales available in the CLDR data repository."},{"ref":"readme.html#testing","title":"Getting Started with Cldr 2.0 - Testing","type":"extras","doc":"Tests cover the full 541 locales defined in CLDR. Since Cldr attempts to maximize the work done at compile time in order to minimize runtime execution, the compilation phase for tests is several minutes. Tests are run on Elixir 1.5 and later. Cldr will not run on Elixir versions before 1.5. Updating the CDLR data repository if installing from Github The CLDR data is maintained in JSON format by the Unicode Consortium. The appropriate content is maintained as submodules in the data directory of this Cldr repository. If this repo has just been cloned then first of all you will need to initialize and retrieve the submodules: git submodule update --init data/cldr-* When CLDR releases new data then the submodules in this repo also need to be updated. To update the CDLR data, git pull each of the submodules. For example: git submodule -q foreach git pull -q origin master From time-to-time ISO will update the repository of ISO3166 language codes. Ensure you have the latest version downloaded: mix cldr.download.iso_currency The file pluralRanges.xml needs to be updated with each release and stored in the ./data directory. This must be manually extracted from the core.zip file downloaded from the CLDR repository. It will be transformed into a json version during the next phase, consolidation. After updating the respository, the locales need to be consolidated into the format used by Cldr. This is done by: mix cldr.consolidate Then you will need to regenerate the language_tags.ebin file by executing the following. Note that MIX_ENV=test is essential since thats how we guarantee all locales are configured. MIX_ENV=test mix cldr.generate_language_tags"},{"ref":"license.html","title":"License","type":"extras","doc":"License Copyright 2018-2019 Kip Cole Licensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License."},{"ref":"changelog.html","title":"Changelog for Cldr v2.11.1","type":"extras","doc":"Changelog for Cldr v2.11.1 This is the changelog for Cldr v2.11.1 released on October 20th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Validate session-based locale in Cldr.Plug.SetLocale. Closes #131. Thanks for @Ray-Wang. Changelog for Cldr v2.11.0 This is the changelog for Cldr v2.11.0 released on October 10th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Update to CLDR data version 36.0.0. Changelog for Cldr v2.10.2 This is the changelog for Cldr v2.10.2 released on September 7th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Use Keyword.get_lazy/3 when retrieving Cldr.default_backend/0 to avoid exceptions when no default backend is configured. Cldr.Number.PluralRule.plural_type/2 has become Cldr.Number.PluralRule.plural_type/3 to better align with other functions that typically use argument, backend, options as their parameters. No user code change is expected as the function heads remain compatible. Changelog for Cldr v2.10.1 This is the changelog for Cldr v2.10.1 released on August 25th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Fix error in the generation of unit preference data Changelog for Cldr v2.10.0 This is the changelog for Cldr v2.10.0 released on August August 25th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Adds unit preference data. This data is used by ex_cldr_units version 2.6 and later to allow localization of units into the preferred units for a given locale or territory. Changelog for Cldr v2.9.0 This is the changelog for Cldr v2.9.0 released on August August 24th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Includes the compound unit fields from units in the generated locale data. This enables formatting of compount units, like the &quot;per&quot; form which is used when there is no predefined unit style. This functionality is enabled in ex_cldr_units version 2.6. Add Cldr.quote/3 and MyApp.Cldr.quote/2 that add locale-specific quotation marks around a string. The locale data files are updated to include this information. Add Cldr.ellipsis/3 and MyApp.Cldr.ellipsis/2 that add locale-specific ellipsis&#39; to a string. The locale data files are updated to include this information. Add Cldr.Config.measurement_system/0 that returns a mapping between a territory and a measurement system (ie does a territory/country use the metric, US or UK system) Changelog for Cldr v2.8.1 This is the changelog for Cldr v2.8.1 released on August 23rd, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Fix the @spec for Cldr.Substitution.substitute/2 Changelog for Cldr v2.8.0 This is the changelog for Cldr v2.8.0 released on August 21st, 2019. For older changelogs please consult the release tag on GitHub Enhancements Adds Cldr.validate_plural_type/1 which will validate if a plural type is one those returned by Cldr.Number.PluralRule.known_plural_types/0 which is also added. These functions are added to support message formatting in the forthcoming ex_cldr_messages package. Adds Cldr.Number.PluralRule.plural_type/2 which returns the plural type for a number. Adds message_formats backend configuration key. This is used by ex_cldr_messages to define custom formats for messages. Bug Fixes Add @spec to parser combinators to remove dialyzer warnings. Ensure that you are using nimble_parsec version 0.5.1 or later if running dialyzer checks. Changelog for Cldr v2.7.2 This is the changelog for Cldr v2.7.2 released on June 14th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Fixes a bug whereby a Gettext backend module may not be compiled at the time that the Cldr backend is being compiled. This can cause compilation errors and may cause the wrong assembly of configured locales. Closes #124. Thanks very much to @erikreedstrom and @epilgrim. Fixes a bug whereby a Cldr backend may not be recognised during compilation of Cldr.Plug.SetLocale. Similar issue to #124. Thanks for @AdrianRibao for the report. Changelog for Cldr v2.7.1 This is the changelog for Cldr v2.7.1 released on June 2nd, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Fix Cldr.known_number_systems/0 by removing the call to Config.known_number_systems/0 which decodes json on each call and use Cldr.known_number_systems/0 which does not. Changelog for Cldr v2.7.0 This is the changelog for Cldr v2.7.0 released on April 22nd, 2019. For older changelogs please consult the release tag on GitHub Enhancements Updates to CLDR version 35.1.0 which is primarily related to the change of Japanese era with the ascension of a new emporer on April 1st. Changelog for Cldr v2.6.2 This is the changelog for Cldr v2.6.2 released on April 16th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Adds Cldr.flag/1 that returns a binary unicode grapheme representing a flag for a given territory The parameters provided to Cldr.Plug.SetLocale.init/1 are now conformed more precisely based upon the provided options. This ensures that the keys :cldr and :gettext are set from other options if they are not provided directly. Bug Fixes Cldr.Plug.SetLocale.init/1 would raise an exception if no :gettext key was specified. This is now corrected. Changelog for Cldr v2.6.1 This is the changelog for Cldr v2.6.1 released on April 13th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Correctly resolves the :data_dir param for a backend module. Thanks to @erikreedstrom for the report. Closes #123. Raises if a backend module configures an :otp_app that is not known Changelog for Cldr v2.6.0 This is the changelog for Cldr v2.6.0 released on March 28th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Updates to CLDR version 35.0.0 released on March 27th 2019. There is one unresolved issue in this implementation related to plural rules for the locale &quot;kw&quot; (Cornish). The plural rule definition for :other in the repository is: &quot;pluralRule-count-other&quot;: &quot; @integer 4~19, 100, 1000000, … @decimal 0.1~0.9, 1.1~1.7, 10.0, 100.0, 1000.0 100000.0 1000000.0, …&quot;, However in rules testing, the values 1000.0, 10000.0 and 100000.0 are resolving to category :two rather than :other. Until this is resolved, these data points are removed from the test data. Changelog for Cldr v2.5.0 This is the changelog for Cldr v2.5.0 released on March 23rd, 2019. For older changelogs please consult the release tag on GitHub Enhancements Adds the global :ex_cldr configuration key :default_backend. Adds Cldr.default_backend/0 which will return the configured default backend or will raise an exception if not is configured. Where appropriate, Cldr.* will now use Cldr.default_backend() as a default parameter. Changelog for Cldr v2.4.3 This is the changelog for Cldr v2.4.3 released on March 20th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Fix Cldr.validate_locale/1 @spec error and remove spurious @dialyzer directives Changelog for Cldr v2.4.2 This is the changelog for Cldr v2.4.2 released on March 15th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Exclude Cldr.Currency from the list of known providers so that it won&#39;t be compiled twice when working with ex_cldr_numbers. Changelog for Cldr v2.4.1 This is the changelog for Cldr v2.4.1 released on March 14th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Makes generation of documentation for backend modules optional. This is implemented by the :generate_docs option to the backend configuration. The default is true. For example: defmodule MyApp.Cldr do use Cldr, default_locale: &quot;en-001&quot;, locales: [&quot;en&quot;, &quot;ja&quot;], gettext: MyApp.Gettext, generate_docs: false end Changelog for Cldr v2.4.0 This is the changelog for Cldr v2.4.0 released on March 10th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Minor restructuring of the locale files. Calendar map keys are harmonised to have the same names and meanings. This would not normally be user visible but a change in data format suggests a minor version bump to easy version management. Restructure the data returned by Cldr.Config.week_info/0 to also encode week days as numbers in the range 1..7 where 1 is Monday. Changelog for Cldr v2.3.2 This is the changelog for Cldr v2.3.2 released on March 8th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Does a better job of detecting a required JSON library and raising at compile time if no such library can be found. In order of priority the search for a JSON library is: the key :json_library under the application key :ex_cldr a configured Phoenix json_library a configured Ecto json_library Jason if configured Poison if configured Changelog for Cldr v2.3.1 This is the changelog for Cldr v2.3.1 released on March 6th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Fix dialyzer errors. In some cases, notably related to nimble_parsec, errors are generated that need to be fixed in a dependency. These errors are added to the .dialyzer_ignore_warnings file for now. Changelog for Cldr v2.3.0 This is the changelog for Cldr v2.3.0 released on March 4th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Adds Cldr.LanguageTag.to_string/1 which converts a Cldr.LanguageTag{} into a language tag string. This is useful when creating a collator that is based upon libicu since that collator will apply the configuration specified by the u extension in the language tag. For example: iex&gt; {:ok, locale} = Cldr.validate_locale &quot;en-US-u-co-phonebk-nu-arab&quot;, MyApp.Cldr iex&gt; Cldr.LanguageTag.to_string(locale) &quot;en-Latn-US-u-ca-phonebk-nu-arab&quot; Bug Fixes Fix a bug when parsing some locale strings which have extensions. An extension may have a list of &quot;keyword-type&quot; pairs or simply &quot;keyword&quot;. Parsing was failing when only the &quot;keyword&quot; form was used. For example the following used to fail, but is now parsed correctly: iex&gt; {:ok, locale} = Cldr.validate_locale &quot;en-US-u-co-ca&quot;, MyApp.Cldr {:ok, %Cldr.LanguageTag{ canonical_locale_name: &quot;en-Latn-US&quot;, cldr_locale_name: &quot;en&quot;, extensions: %{}, gettext_locale_name: nil, language: &quot;en&quot;, language_subtags: [], language_variant: nil, locale: %{calendar: &quot;gregory&quot;, collation: &quot;standard&quot;}, private_use: [], rbnf_locale_name: &quot;en&quot;, requested_locale_name: &quot;en-US&quot;, script: &quot;Latn&quot;, territory: &quot;US&quot;, transform: %{} }} Fix a race condition when starting up the compile-time locale cache Changelog for Cldr v2.2.7 This is the changelog for Cldr v2.2.7 released on February 23rd, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Correctly validates locales that are not pre-compiled into a backend. At compile time, all configured locales are generated from the CLDR data. However not all valid locales can be predefined - especially those that have variants, subtags or extensions or use a different casing to the canonical form. For example, the following would fail in prior releases even though it is perfectly valid since language tags are defined to be case insensitive: iex&gt; MyApp.Cldr.validate_locale &quot;en-au&quot; {:error, {Cldr.UnknownLocaleError, &quot;The locale \\&quot;en-au\\&quot; is not known.&quot;}} Similarly, it is expected that both the POSIX and IEEE formats of a language tag are acceptable, meaning that a - or _ should be acceptable. Again, in prior releases this would result in an error: iex&gt; MyApp.Cldr.validate_locale &quot;en_AU&quot; {:error, {Cldr.UnknownLocaleError, &quot;The locale \\&quot;en_AU\\&quot; is not known.&quot;}} Lastly, when using locale extensions, subtags or variants the validation would fail: MyApp.Cldr.validate_locale &quot;en-u-ca-buddhist&quot; {:error, {Cldr.UnknownLocaleError, &quot;The locale \\&quot;en_AU\\&quot; is not known.&quot;}} Each of these examples now correctly validates: iex&gt; TestBackend.Cldr.validate_locale &quot;en-au&quot; {:ok, %Cldr.LanguageTag{ canonical_locale_name: &quot;en-Latn-AU&quot;, cldr_locale_name: &quot;en-AU&quot;, extensions: %{}, gettext_locale_name: &quot;en&quot;, language: &quot;en&quot;, language_subtags: [], language_variant: nil, locale: %{}, private_use: [], rbnf_locale_name: &quot;en&quot;, requested_locale_name: &quot;en-AU&quot;, script: &quot;Latn&quot;, territory: &quot;AU&quot;, transform: %{} }} iex&gt; TestBackend.Cldr.validate_locale &quot;en_au&quot; {:ok, %Cldr.LanguageTag{ canonical_locale_name: &quot;en-Latn-AU&quot;, cldr_locale_name: &quot;en-AU&quot;, extensions: %{}, gettext_locale_name: &quot;en&quot;, language: &quot;en&quot;, language_subtags: [], language_variant: nil, locale: %{}, private_use: [], rbnf_locale_name: &quot;en&quot;, requested_locale_name: &quot;en-AU&quot;, script: &quot;Latn&quot;, territory: &quot;AU&quot;, transform: %{} }} iex&gt; TestBackend.Cldr.validate_locale &quot;en-u-ca-buddhist&quot; {:ok, %Cldr.LanguageTag{ canonical_locale_name: &quot;en-Latn-US&quot;, cldr_locale_name: &quot;en&quot;, extensions: %{}, gettext_locale_name: &quot;en&quot;, language: &quot;en&quot;, language_subtags: [], language_variant: nil, locale: %{calendar: :buddhist}, private_use: [], rbnf_locale_name: &quot;en&quot;, requested_locale_name: &quot;en&quot;, script: &quot;Latn&quot;, territory: &quot;US&quot;, transform: %{} }} Changelog for Cldr v2.2.6 This is the changelog for Cldr v2.2.6 released on February 23rd, 2019. For older changelogs please consult the release tag on GitHub Enhancements Adds Cldr.Config.territory_currency_data/0 that maps a territory code (like &quot;US&quot;) to a list of currencies reflecting the historic and current usage of currencies in that territory. Changelog for Cldr v2.2.5 This is the changelog for Cldr v2.2.5 released on February 18th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Remove most dialyzer errors Fix documentation syntax errors Fix regex for parsing currency names into currency strings Changelog for Cldr v2.2.4 This is the changelog for Cldr v2.2.4 released on February 10th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Ensure the global default locale (currently &quot;en-001&quot;) is always configured Enhancements Log a warning if a CLDR provider module could not be found Changelog for Cldr v2.2.3 This is the changelog for Cldr v2.2.3 released on February 9th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Fix parsing of currency names that have date ranges or annotations within them like &quot;US dollar (next day)&quot; and &quot;Afghan afghani (1927–2002)&quot; Changelog for Cldr v2.2.2 This is the changelog for Cldr v2.2.2 released on February 9th, 2019. For older changelogs please consult the release tag on GitHub Enhancements add Cldr.Config.currencies_for/2 to return a map of the currency definition for a locale Changelog for Cldr v2.2.1 This is the changelog for Cldr v2.2.1 released on January 30th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Correctly add the gettext locale to the language tag returned by &lt;backend&gt;.default_locale and Cldr.default_locale/2. Thanks to @erikreedstrom. Closes #106. Enhancements Added a section on migrating from Cldr 1.x to 2.x. Changelog for Cldr v2.2.0 This is the changelog for Cldr v2.2.0 released on December 23nd, 2018. For older changelogs please consult the release tag on GitHub Enhancements Bump nimble_parsec to version 0.5 which has some breaking changes from 0.4 that affects the language tag parser. Use IO.warn/1 for compiler warnings related to global configuration and Cldr providers configuration for a backend. Changelog for Cldr v2.1.0 This is the changelog for Cldr v2.1.0 released on December 1st, 2018. For older changelogs please consult the release tag on GitHub Bug Fixes Don&#39;t issue a bogus global config deprecation warning. Enhancements Revises the Cldr provider strategy - again. Rather than try to auto-discover available provider modules and configuring them automatically they are now configured under the :provider key. The readme contains further information on configuring providers. For example: defmodule MyApp.Cldr do use Cldr, locales: [&quot;en&quot;, &quot;zh&quot;], default_locale: &quot;en&quot;, providers: [Cldr.Number, Cldr.List] end The default behaviour is the same as Cldr 2.0 in that all known cldr providers are configured. Changelog for Cldr v2.0.4 This is the changelog for Cldr v2.0.4 released on November 26th, 2018. For older changelogs please consult the release tag on GitHub Bug fixes Dependency plugin check was using Mix.Project.in_project/3 which actually changes directory which during compilation is a bad thing (since compilation is in parallel and within a single Unix process). The plugin dependency list is now static. Thanks to @robotvert. Closes #93. Changelog for Cldr v2.0.3 This is the changelog for Cldr v2.0.3 released on November 25th, 2018. For older changelogs please consult the release tag on GitHub Bug fixes Check for a json library existence as early as possible in the compile cycle since it is required during compilation of Cldr. Changelog for Cldr v2.0.2 This is the changelog for Cldr v2.0.2 released on November 24th, 2018. For older changelogs please consult the release tag on GitHub Enhancements Move minimal Decimal version to 1.5 Bug fixes Cldr.Substitution.substitute/2 now conforms to its documentation and substitutes a list of terms into a list format Changelog for Cldr v2.0.1 This is the changelog for Cldr v2.0.1 released on November 22, 2018. For older changelogs please consult the release tag on GitHub Bug fixes Fixes a bug whereby a backend configured with locales, but no default locale (and no global configuration), would crash during compilation Changelog for Cldr v2.0.0 This is the changelog for Cldr v2.0.0 released on November 22, 2018. For older changelogs please consult the release tag on GitHub Enhancements See also Breaking Changes below. Transforms the regex&#39;s for currency spacing to be compatible with the elixir regex engine. This supports improved conformance for currency formatting in ex_cldr_numbers Removes the need for Phoenix as a dependency in tests. Thanks to @lostkobrakai. Closes #84. Print deprecation message if the global config is used for more than :json_library and :default_locale Align Cldr/get_locale/1/0 and Cldr.put_locale/2/1 with Gettext. See Cldr.get_locale/1, Cldr.get_locale/0, Cldr.put_locale/2 and Cldr.put_locale/1 Improve performance of Cldr.Gettext.Plural and align its return better with Gettext Add the &#39;miscellaneous&#39; number formats to the locale definition files. This allows formatting of &quot;at least&quot;, &quot;approximately&quot;, &quot;at most&quot; and &quot;range&quot;. These formats will be used in ex_cldr_numbers. Purpose of the changes Version 2.0 of Cldr is focused on re-architecting the module structure to more closely follow the model set by Phoenix, Ecto, Gettext and others that also rely on generating a public API at compile time. In Cldr version 1.x, the compile functions were all hosted within the ex_cldr package itself which has created several challenges: Only one configuration was possible per installation Dependency compilation order couldn&#39;t be determined which meant that when Gettext was configured a second, forced, compilation phase was required whenever the configuration changed Code in the ex_cldr _build directory would be modified when the configuration changed New structure and configuration In line with the recommended strategy for configurable library applications, Cldr now requires a backend module be defined that hosts the configuration and public API. This is similar to the strategy used by Gettext, Ecto, Phoenix and others. These backend modules are defined like this: defmodule MyApp.Cldr do use Cldr, locales: [&quot;en&quot;, &quot;zh&quot;] end For further information on configuration, consult the readme. Migrating from Cldr 1.x to Cldr version 2.x Although the api structure is the same in both releases, the move to a backend module hosting configuration and the public API requires changes in applications using Cldr version 1.x. The steps to migrate are: Change the dependency in mix.exs to {:ex_cldr, &quot;~&gt; 2.0&quot;} Define a backend module to host the configuration and public API. It is recommended that the module be named MyApp.Cldr since this will ease migration through module aliasing. Change calls to Cldr.function_name to MyApp.Cldr.function_name. The easiest way to do this is to alias the backend module. For example: defmodule MyApp.SomeModule do # alias the backend module so that calls to Cldr functions still work alias MyApp.Cldr def some_function do IO.puts Cldr.known_locale_names end end Breaking Changes Configuration has changed to focus on the backend module, then otp app, then global config. All applications are required to define a backend module. The Public API moves to a configured backend module. Functions previous called on Cldr should be called on MyApp.Cldr. The ~L sigil has been removed. The public api functions support either a locale name (like &quot;en&quot;) or a language tag. Cldr.Plug.AcceptLanguage and Cldr.Plug.SetLocale need to have a config key :cldr to specify the Cldr backend to be used. The Mix compiler :cldr is obsolete. It still exists so configuration doesn&#39;t break but its no a :noop. It should be removed from your configuration. Cldr.Config.get_locale/1 now takes a config or backend parameter and has become Cldr.Config.get_locale/2. Cldr.get_current_locale/0 is renamed to Cldr.get_locale/0 to better align with Gettext Cldr.put_current_locale/1 is renamed to Cldr.put_locale/1 to better align with Gettext"},{"ref":"feature_requests.html","title":"Feature Requests","type":"extras","doc":"Feature Requests This page uses Feathub to capture feature requests and votes. Click on the panel to view, add or vote on feature requests."}]